@@ -95,7 +95,7 @@ def list_iam_role_attached_policies(client, role_name):
 @AWSRetry.jittered_backoff()
 def list_iam_users(client, path=None):
     args = {}
-    if path is None:
+    if path is not None:
         args = {"PathPrefix": path}
     paginator = client.get_paginator("list_users")
     return paginator.paginate(**args).build_full_result()["Users"]
@@ -160,9 +160,18 @@ def get_iam_access_keys(client, user):
 
 @IAMErrorHandler.list_error_handler("get user")
 @AWSRetry.jittered_backoff()
-def get_iam_user(client, user):
+def get_iam_user(client, user, normalize=True):
     results = client.get_user(UserName=user)
-    return normalize_iam_user(results.get("User", []))
+    if normalize:
+        return normalize_iam_user(results.get("User", []))
+    return results.get("User", [])
+
+
+@IAMErrorHandler.list_error_handler("get user tags")
+@AWSRetry.jittered_backoff()
+def list_iam_user_tags(client, user):
+    results = client.list_user_tags(UserName=user)
+    return results.get("Tags", [])
 
 
 def find_iam_managed_policy_by_name(client, name):
@@ -334,7 +343,7 @@ def tag_iam_instance_profile(client, name, tags):
     if not tags:
         return
     boto3_tags = ansible_dict_to_boto3_tag_list(tags or {})
-    result = client.tag_instance_profile(InstanceProfileName=name, Tags=boto3_tags)
+    client.tag_instance_profile(InstanceProfileName=name, Tags=boto3_tags)
 
 
 @IAMErrorHandler.common_error_handler("untag instance profile")
@@ -446,8 +455,6 @@ def normalize_iam_access_keys(access_keys: BotoResourceList) -> AnsibleAWSResour
 def normalize_iam_instance_profile(profile: BotoResource) -> AnsibleAWSResource:
     """
     Converts a boto3 format IAM instance profile into "Ansible" format
-
-    _v7_compat is deprecated and will be removed in release after 2025-05-01 DO NOT USE.
     """
     transforms = {"Roles": _normalize_iam_roles}
     transformed_profile = boto3_resource_to_ansible_dict(profile, nested_transforms=transforms)
@@ -458,10 +465,10 @@ def normalize_iam_role(role: BotoResource, _v7_compat: bool = False) -> AnsibleA
     """
     Converts a boto3 format IAM instance role into "Ansible" format
 
-    _v7_compat is deprecated and will be removed in release after 2025-05-01 DO NOT USE.
+    _v7_compat is deprecated and will be removed in release after 2026-05-01 DO NOT USE.
     """
     transforms = {"InstanceProfiles": _normalize_iam_instance_profiles}
-    ignore_list = [] if _v7_compat else ["AssumeRolePolicyDocument"]
+    ignore_list = ["AssumeRolePolicyDocument"]
     transformed_role = boto3_resource_to_ansible_dict(role, nested_transforms=transforms, ignore_list=ignore_list)
     if _v7_compat and role.get("AssumeRolePolicyDocument"):
         transformed_role["assume_role_policy_document_raw"] = role["AssumeRolePolicyDocument"]
