@@ -403,8 +403,8 @@ diff:
 
 """
 
-from ansible.module_utils._text import to_text
 from ansible.module_utils.basic import AnsibleModule
+from ansible.module_utils.common.text.converters import to_text
 from ansible.module_utils.connection import Connection, ConnectionError
 
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.netconf.netconf import (
