@@ -1,13 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: sites_info
-short_description: Information module for Sites Info
+short_description: Information module for Sites
 description:
-  - This module represents an alias of the module sites_v1_info
+  - Get all Sites.
+  - Get sites.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -30,32 +33,40 @@ options:
     type: str
   _unitsOfMeasure:
     description:
-      - _unitsOfMeasure query parameter. Floor units of measure.
+      - _unitsOfMeasure query parameter. Floor units
+        of measure.
     type: str
   offset:
     description:
-      - Offset query parameter. The first record to show for this page; the first
-        record is numbered 1.
+      - Offset query parameter. The first record to
+        show for this page; the first record is numbered
+        1.
     type: float
   limit:
     description:
-      - Limit query parameter. The number of records to show for this page;The minimum
-        is 1, and the maximum is 500.
+      - Limit query parameter. The number of records
+        to show for this page;The minimum is 1, and
+        the maximum is 500.
     type: float
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Site Design GetSitesV1
-    description: Complete reference of the GetSitesV1 API.
+  - name: Cisco DNA Center documentation for Site Design
+      GetSites
+    description: Complete reference of the GetSites
+      API.
     link: https://developer.cisco.com/docs/dna-center/#!get-sites
 notes:
-  - SDK Method used are site_design.SiteDesign.get_sites_v1,
-  - Paths used are get /dna/intent/api/v1/sites,
-  - It should be noted that this module is an alias of sites_v1_info
+  - SDK Method used are
+    site_design.SiteDesign.get_sites,
+  - Paths used are
+    get /dna/intent/api/v1/sites,
 """
+
 EXAMPLES = r"""
-- name: Get all Sites Info
+---
+- name: Get all Sites
   cisco.dnac.sites_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -96,7 +107,8 @@ dnac_response:
           "unitsOfMeasure": "string",
           "type": "string",
           "id": "string",
-          "parentId": "string"
+          "parentId": "string",
+          "siteHierarchyId": "string"
         }
       ],
       "version": "string"
