@@ -1,13 +1,21 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: system_performance_historical_info
-short_description: Information module for System Performance Historical Info
+short_description: Information module for System Performance
+  Historical
 description:
-  - This module represents an alias of the module system_performance_historical_v1_info
+  - Get all System Performance Historical. - > Retrieves
+    the average values of cluster key performance indicators
+    KPIs , like CPU utilization, memory utilization
+    or network rates grouped by time intervals within
+    a specified time range. The data will be available
+    from the past 24 hours.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -18,36 +26,42 @@ options:
     type: dict
   kpi:
     description:
-      - Kpi query parameter. Fetch historical data for this kpi. Valid values cpu,memory,network.
+      - Kpi query parameter. Fetch historical data for
+        this kpi. Valid values cpu,memory,network.
     type: str
   startTime:
     description:
       - >
-        StartTime query parameter. This is the epoch start time in milliseconds from
-        which performance indicator
-        need to be fetched.
+        StartTime query parameter. This is the epoch
+        start time in milliseconds from which performance
+        indicator need to be fetched.
     type: float
   endTime:
     description:
       - >
-        EndTime query parameter. This is the epoch end time in milliseconds upto which
-        performance indicator need to
-        be fetched.
+        EndTime query parameter. This is the epoch end
+        time in milliseconds upto which performance
+        indicator need to be fetched.
     type: float
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Health and Performance SystemPerformanceHistoricalAPIV1
-    description: Complete reference of the SystemPerformanceHistoricalAPIV1 API.
+  - name: Cisco DNA Center documentation for Health
+      and Performance SystemPerformanceHistoricalAPI
+    description: Complete reference of the SystemPerformanceHistoricalAPI
+      API.
     link: https://developer.cisco.com/docs/dna-center/#!system-performance-historical-api
 notes:
-  - SDK Method used are health_and_performance.HealthAndPerformance.system_performance_historical,
-  - Paths used are get /dna/intent/api/v1/diagnostics/system/performance/history,
-  - It should be noted that this module is an alias of system_performance_historical_v1_info
+  - SDK Method used are
+    health_and_performance.HealthAndPerformance.system_performance_historical,
+  - Paths used are
+    get /dna/intent/api/v1/diagnostics/system/performance/history,
 """
+
 EXAMPLES = r"""
-- name: Get all System Performance Historical Info
+---
+- name: Get all System Performance Historical
   cisco.dnac.system_performance_historical_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
