@@ -1,14 +1,19 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: templates_template_id_network_profiles_for_sites_count_info
-short_description: Information module for Templates Template Id Network Profiles For
-  Sites Count Info
+short_description: Information module for Templates
+  Template Id Network Profiles For Sites Count
 description:
-  - This module represents an alias of the module templates_template_id_network_profiles_for_sites_count_v1_info
+  - Get all Templates Template Id Network Profiles For
+    Sites Count.
+  - Retrieves the count of network profiles that a CLI
+    template has been attached to by the template ID.
 version_added: '6.17.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -19,26 +24,29 @@ options:
     type: dict
   templateId:
     description:
-      - TemplateId path parameter. The `id` of the template, retrievable from `GET
-        /intent/api/v1/templates`.
+      - TemplateId path parameter. The `id` of the template,
+        retrievable from `GET /intent/api/v1/templates`.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Configuration Templates RetrieveCountOfNetworkProfilesAttachedToACLITemplateV1
-    description: Complete reference of the RetrieveCountOfNetworkProfilesAttachedToACLITemplateV1
+  - name: Cisco DNA Center documentation for Configuration
+      Templates RetrieveCountOfNetworkProfilesAttachedToACLITemplate
+    description: Complete reference of the RetrieveCountOfNetworkProfilesAttachedToACLITemplate
       API.
-    link:
-      https://developer.cisco.com/docs/dna-center/#!retrieve-count-of-network-profiles-attached-to-acli-template
+    link: https://developer.cisco.com/docs/dna-center/#!retrieve-count-of-network-profiles-attached-to-acli-template
 notes:
   - SDK Method used are
-    configuration_templates.ConfigurationTemplates.retrieve_count_of_network_profiles_attached_to_acl_i_template_v1,
-  - Paths used are get /dna/intent/api/v1/templates/{templateId}/networkProfilesForSites/count,
-  - It should be noted that this module is an alias of templates_template_id_network_profiles_for_sites_count_v1_info
+    configuration_templates.ConfigurationTemplates.retrieve_count_of_network_profiles_attached_to_acl_i_template,
+  - Paths used are
+    get /dna/intent/api/v1/templates/{templateId}/networkProfilesForSites/count,
 """
+
 EXAMPLES = r"""
-- name: Get all Templates Template Id Network Profiles For Sites Count Info
+---
+- name: Get all Templates Template Id Network Profiles
+    For Sites Count
   cisco.dnac.templates_template_id_network_profiles_for_sites_count_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
