@@ -256,6 +256,12 @@ options:
           - Relationship to the boot iSCSI Policy.
           - Only applicable for attached target platform.
         type: str
+      pin_group_name:
+        description:
+          - Pingroup name associated to vNIC for static pinning.
+          - LCP deploy will resolve pingroup name and fetches the corresponding uplink port/port channel to pin the vNIC traffic.
+          - Only applicable for attached target platform.
+        type: str
       usnic_settings:
         description:
           - USNIC settings when connection_type is 'usnic'.
@@ -433,6 +439,37 @@ EXAMPLES = r'''
         state: present
     state: present
 
+- name: Create a LAN Connectivity Policy with pin group for static pinning
+  cisco.intersight.intersight_lan_connectivity_policy:
+    api_private_key: "{{ api_private_key }}"
+    api_key_id: "{{ api_key_id }}"
+    organization: "default"
+    name: "fi-attached-pinned-policy"
+    description: "LAN connectivity policy with static uplink pinning"
+    target_platform: "attached"
+    azure_qos_enabled: false
+    iqn_allocation_type: "None"
+    placement_mode: "custom"
+    vnics:
+      - name: "pinned-vnic"
+        order: 0
+        cdn_source: "vnic"
+        mac_address_type: "pool"
+        mac_pool_name: "default-mac-pool"
+        auto_slot_id: true
+        auto_pci_link: true
+        auto_vnic_placement_enabled: false
+        switch_id: "A"
+        failover_enabled: false
+        fabric_eth_network_group_policy_name: "default-network-group"
+        fabric_eth_network_control_policy_name: "default-network-control"
+        eth_qos_policy_name: "default-qos-policy"
+        eth_adapter_policy_name: "default-adapter-policy"
+        pin_group_name: "pingroup-a"
+        connection_type: "none"
+        state: present
+    state: present
+
 - name: Create a LAN Connectivity Policy with automatic vNIC placement
   cisco.intersight.intersight_lan_connectivity_policy:
     api_private_key: "{{ api_private_key }}"
@@ -874,7 +911,8 @@ def resolve_vnic_policy_moids(intersight, policy_cache, module, vnic_config, tar
     Resolve all policy MOIDs for a vNIC configuration based on target platform.
     """
     policy_mappings = get_vnic_policy_mappings(target_platform, vnic_config)
-    return resolve_policy_moids_from_mappings(intersight, policy_cache, module, vnic_config, policy_mappings)
+    organization_name = module.params['organization']
+    return resolve_policy_moids_from_mappings(intersight, policy_cache, module, vnic_config, policy_mappings, organization_name)
 
 
 def build_vnic_api_body(intersight, policy_cache, module, vnic_config, lan_connectivity_policy_moid):
@@ -913,7 +951,8 @@ def build_standalone_vnic_api_body(intersight, policy_cache, module, vnic_config
     vnic_api_body.update(policy_moids)
 
     # Add common connection type settings
-    connection_settings = build_connection_settings(intersight, policy_cache, module, vnic_config)
+    organization_name = module.params['organization']
+    connection_settings = build_connection_settings(intersight, policy_cache, module, vnic_config, organization_name)
     vnic_api_body.update(connection_settings)
 
     return vnic_api_body
@@ -976,9 +1015,14 @@ def build_fi_attached_vnic_api_body(intersight, policy_cache, module, vnic_confi
     vnic_api_body.update(policy_moids)
 
     # Add common connection type settings
-    connection_settings = build_connection_settings(intersight, policy_cache, module, vnic_config)
+    organization_name = module.params['organization']
+    connection_settings = build_connection_settings(intersight, policy_cache, module, vnic_config, organization_name)
     vnic_api_body.update(connection_settings)
 
+    # Add pin group name if specified
+    if vnic_config.get('pin_group_name'):
+        vnic_api_body['PinGroupName'] = vnic_config['pin_group_name']
+
     return vnic_api_body
 
 
@@ -1048,6 +1092,7 @@ def main():
         auto_pci_link=dict(type='bool', default=True),
         pci_link_assignment_mode=dict(type='str', choices=['Custom', 'Load-Balanced']),
         auto_vnic_placement_enabled=dict(type='bool', default=False),
+        pin_group_name=dict(type='str'),
     )
     # Add connection settings argument specs
     vnic_options.update(get_common_settings_argument_spec())
@@ -1110,12 +1155,14 @@ def main():
 
             # Resolve IQN pool MOID if specified
             if intersight.module.params['iqn_pool_name']:
-                iqn_pool_moid = intersight.get_moid_by_name(
+                iqn_pool_moid = intersight.get_moid_by_name_and_org(
                     resource_path='/iqnpool/Pools',
-                    resource_name=intersight.module.params['iqn_pool_name']
+                    resource_name=intersight.module.params['iqn_pool_name'],
+                    organization_name=intersight.module.params['organization']
                 )
                 if not iqn_pool_moid:
-                    intersight.module.fail_json(msg=f"IQN Pool '{intersight.module.params['iqn_pool_name']}' not found")
+                    intersight.module.fail_json(msg=f"IQN Pool '{intersight.module.params['iqn_pool_name']}' not found in organization ' \
+                    {intersight.module.params['organization']}'")
                 intersight.api_body['IqnPool'] = iqn_pool_moid
 
             if intersight.module.params['static_iqn_name']:
@@ -1149,10 +1196,12 @@ def main():
 
             # Configure the vNIC (create/update/delete)
             resource_path = '/vnic/EthIfs'
+            # Filter by both vNIC name AND LAN Connectivity Policy to avoid affecting vNICs in other policies
+            custom_filter = f"Name eq '{vnic_config['name']}' and LanConnectivityPolicy.Moid eq '{lan_connectivity_policy_moid}'"
             intersight.configure_secondary_resource(
                 resource_path=resource_path,
-                resource_name=vnic_config['name'],
-                state=vnic_state
+                state=vnic_state,
+                custom_filter=custom_filter
             )
 
             # Save the vNIC response only if it's present
