@@ -36,7 +36,6 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
                     $""",
                 re.VERBOSE,
             ),
-            "compval": "name",
             "setval": "interface {{ name }}",
             "result": {"{{ name }}": {"name": "{{ name }}"}},
             "shared": True,
@@ -59,7 +58,7 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
             "name": "version",
             "getval": re.compile(
                 r"""
-                \s+standby\sversion\s(?P<version>\d+)
+                \s*standby\sversion\s(?P<version>\d+)
                 $""", re.VERBOSE,
             ),
             "setval": "standby version {{ version|string }}",
@@ -100,23 +99,61 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
             "setval": "standby bfd",
             "result": {
                 "{{ name }}": {
-                    "bfd": "{{ True }}",
+                    "bfd": True,
                 },
             },
         },
         {
-            "name": "use-bia",
+            "name": "use_bia",
             "getval": re.compile(
                 r"""
-                \s+standby\suse-bia\sscope\sinterface
+                \s+standby\suse-bia
+                (\s(?P<bia>\sscope\sinterface))?
                 $""", re.VERBOSE,
             ),
-            "setval": "standby use-bia scope interface",
+            "remval": "standby use-bia",
+            "setval": "standby use-bia"
+            "{{ ' scope interface' if use_bia.scope|d(False) is defined else ''}}",
             "result": {
                 "{{ name }}": {
                     "use_bia": {
-                        "scope": {
-                            "interface": "{{ True }}",
+                        "set": True,
+                        "scope": "{{ not not bia }}",
+                    },
+                },
+            },
+        },
+        {
+            "name": "timers",
+            "getval": re.compile(
+                r"""
+                \s*standby\s(?P<grp_no>\d+)
+                \s*timers
+                (?:\smsec\s(?P<msec_hello_interval>\d+)|\s(?P<hello_interval>\d+))
+                (?:\smsec\s(?P<msec_hold_time>\d+)|\s(?P<hold_time>\d+))
+                $""", re.VERBOSE,
+            ),
+            "setval": "standby"
+            "{{ ' ' + group_no|string if group_no is defined else ''}}"
+            " timers"
+            "{{ (' msec ' + timer.msec.hello_interval|string) "
+            "if timer.msec.hello_interval is defined "
+            "else (' ' + timer.hello_interval|string) "
+            "if timer.hello_interval is defined else '' }}"
+            "{{ (' msec ' + timer.msec.hold_time|string) "
+            "if timer.msec.hold_time is defined "
+            "else (' ' + timer.hold_time|string) "
+            "if timer.hold_time is defined else '' }}",
+            "result": {
+                "{{ name }}": {
+                    "group_{{ grp_no|string }}": {
+                        "timers": {
+                            "hello_interval": "{{ hello_interval }}",
+                            "hold_time": "{{ hold_time }}",
+                            "msec": {
+                                "hello_interval": "{{ msec_hello_interval }}",
+                                "hold_time": "{{ msec_hold_time }}",
+                            },
                         },
                     },
                 },
@@ -126,77 +163,16 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
             "name": "follow",
             "getval": re.compile(
                 r"""
-                \s+standby\sfollow\s(?P<follow>.+)
+                \s*standby\s(?P<grp_no>\d+)
+                \s*follow\s(?P<description>.+$)
                 $""", re.VERBOSE,
             ),
-            "setval": "standby follow {{ follow }}",
+            "setval": "standby {{ group_no|string if group_no is defined else '' }} follow {{ follow }}",
             "result": {
                 "{{ name }}": {
-                    "follow": "{{ follow }}",
-                },
-            },
-        },
-        {
-            "name": "timers.msec",
-            "getval": re.compile(
-                r"""
-                \s+standby\s*(?P<group_no>\d+)?\s*timers\smsec\s(?P<hello_interval>\d+)\smsec\s(?P<hold_time>\d+)
-                $""", re.VERBOSE,
-            ),
-            "setval": "standby {{ timers.group_no|string if timers.group_no is defined else '' }} timers msec"
-            " {{ timers.msec.hello_interval|string }} msec {{ timers.msec.hold_time|string }}",
-            "result": {
-                "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
-                        "timers": {
-                            "msec": {
-                                "hello_interval": "{{ hello_interval }}",
-                                "hold_time": "{{ hold_time }}",
-                            },
-                        },
-                    }],
-                },
-            },
-        },
-        {
-            "name": "timers",
-            "getval": re.compile(
-                r"""
-                \s+standby\s*(?P<group_no>\d+)?\s*timers\s(?P<hello_interval>\d+)\s(?P<hold_time>\d+)
-                $""", re.VERBOSE,
-            ),
-            "setval": "standby {{ timers.group_no|string if timers.group_no is defined else '' }} timers {{ timers.hello_interval }} {{ timers.hold_time }}",
-            "result": {
-                "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
-                        "timers": {
-                            "hello_interval": "{{ hello_interval }}",
-                            "hold_time": "{{ hold_time }}",
-                        },
-                    }],
-                },
-            },
-        },
-        {
-            "name": "follow.follow",
-            "getval": re.compile(
-                r"""
-                \s*standby
-                (?:\s+(?P<group_no>\d+))
-                \s+follow\s+
-                (?P<follow>.+)
-                $""", re.VERBOSE,
-            ),
-            "compval": "follow",
-            "setval": "standby {{ follow.group_no|string if follow.group_no is defined else '' }} follow {{ follow.follow }}",
-            "result": {
-                "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
-                        "follow": "{{ follow }}",
-                    }],
+                    "group_{{ grp_no|string }}": {
+                        "follow": "{{ description }}",
+                    },
                 },
             },
         },
@@ -204,16 +180,15 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
             "name": "priority",
             "getval": re.compile(
                 r"""
-                \s+standby\s*(?P<group_no>\d+)?\s*priority\s(?P<priority>\d+)
+                \s+standby\s*(?P<grp_no>\d+)?\s*priority\s(?P<priority>\d+)
                 $""", re.VERBOSE,
             ),
-            "setval": "standby {{ priority.group_no|string if priority.group_no is defined else '' }} priority {{ priority.priority|string }}",
+            "setval": "standby {{ group_no|string if group_no is defined else '' }} priority {{ priority|string }}",
             "result": {
                 "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
+                    "group_{{ grp_no|string }}": {
                         "priority": "{{ priority }}",
-                    }],
+                    },
                 },
             },
         },
@@ -221,7 +196,7 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
             "name": "preempt",
             "getval": re.compile(
                 r"""
-                \s+standby\s*(?P<group_no>\d+)?\s*preempt
+                \s+standby\s*(?P<grp_no>\d+)?\s*preempt
                 (\s(?P<delay>delay))?
                 (\sminimum\s(?P<minimum>\d+))?
                 (\sreload\s(?P<reload>\d+))?
@@ -229,10 +204,10 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
                 $""", re.VERBOSE,
             ),
             "remval": "standby "
-                      "{{ preempt.group_no|string if preempt.group_no is defined else ''}}"
+                      "{{ group_no|string if group_no is defined else ''}}"
                       " preempt",
             "setval": "standby "
-                      "{{ preempt.group_no|string if preempt.group_no is defined else ''}}"
+                      "{{ group_no|string if group_no is defined else ''}}"
                       " preempt"
                       "{{ ' delay' if preempt.delay|d(False) else ''}}"
                       "{{ ' minimum ' + preempt.minimum|string if preempt.minimum is defined else ''}}"
@@ -240,8 +215,7 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
                       "{{ ' sync ' + preempt.sync|string if preempt.sync is defined else ''}}",
             "result": {
                 "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
+                    "group_{{ grp_no|string }}": {
                         "preempt": {
                             "enabled": True,
                             "delay": "{{ not not delay }}",
@@ -249,7 +223,7 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
                             "reload": "{{ reload }}",
                             "sync": "{{ sync }}",
                         },
-                    }],
+                    },
                 },
             },
         },
@@ -257,7 +231,7 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
             "name": "track",
             "getval": re.compile(
                 r"""
-                \s+standby\s*(?P<group_no>\d+)?\s*track\s(?P<track_no>\d+)
+                \s+standby\s*(?P<grp_no>\d+)\s*track\s(?P<track_no>\d+)
                 (\sdecrement\s(?P<decrement>\d+))?
                 (\s(?P<shutdown>shutdown))?
                 $""", re.VERBOSE,
@@ -270,14 +244,13 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
                       "{{ ' shutdown' if track.shutdown|d(False) else ''}}",
             "result": {
                 "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
+                    "group_{{ grp_no|string }}": {
                         "track": [{
                             "track_no": "{{ track_no }}",
                             "decrement": "{{ decrement }}",
                             "shutdown": "{{ not not shutdown }}",
                         }],
-                    }],
+                    },
                 },
             },
         },
@@ -285,7 +258,7 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
             "name": "ip",
             "getval": re.compile(
                 r"""
-                \s+standby\s*(?P<group_no>\d+)?\s*ip\s+(?P<virtual_ip>\S+)
+                \s+standby\s*(?P<grp_no>\d+)\s*ip\s+(?P<virtual_ip>\S+)
                 (\s(?P<secondary>secondary))?
                 $""", re.VERBOSE,
             ),
@@ -296,65 +269,53 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
                       "{{ ' secondary' if ip.secondary|d(False) else ''}}",
             "result": {
                 "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
+                    "group_{{ grp_no|string }}": {
                         "ip": [{
                             "virtual_ip": "{{ virtual_ip }}",
                             "secondary": "{{ not not secondary }}",
                         }],
-                    }],
+                    },
                 },
             },
         },
         {
-            "name": "autoconfig",
+            "name": "ipv6.autoconfig",
             "getval": re.compile(
                 r"""
-                \s*standby
-                (?:\s+(?P<group_no>\d+))
-                \s+ipv6
-                (?:\s+(?P<autoconfig>autoconfig))
+                \s*standby(\s+(?P<grp_no>\d+))\s+ipv6\sautoconfig
                 $""", re.VERBOSE,
             ),
             "setval": "standby"
                       "{{ ' ' + group_no|string if group_no is defined else ''}}"
                       " ipv6"
-                      "{{ ' autoconfig' if autoconfig|d(False) else ''}}",
+                      "{{ ' autoconfig' if ipv6.autoconfig|d(False) else ''}}",
             "result": {
                 "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
+                    "group_{{ grp_no|string }}": {
                         "ipv6": {
-                            "autoconfig": "{{ not not autoconfig }}",
+                            "autoconfig": True,
                         },
-                    }],
+                    },
                 },
             },
         },
         {
-            "name": "address",
+            "name": "ipv6_addr",
             "getval": re.compile(
                 r"""
-                \s+standby
-                (\s(?P<group_no>\d+))
-                \sipv6
+                \s+standby(\s(?P<grp_no>\d+))\sipv6
                 (\s(?P<address>\S+))
                 $""", re.VERBOSE,
             ),
             "setval": "standby"
-                      "{{ ' ' + group_no|string if group_no is defined else ''}}"
+                      "{{ ' ' + ipv6_addr.group_no|string if ipv6_addr.group_no is defined else ''}}"
                       " ipv6"
-                      "{{ ' ' + address if address is defined else ''}}",
+                      "{{ ' ' + ipv6_addr.address if ipv6_addr.address is defined else ''}}",
             "result": {
                 "{{ name }}": {
-                    "standby_groups": [
-                        {
-                            "group_no": "{{ group_no }}",
-                            "process_ipv6": True,
-                            "ipv6_address{{ address }}": "{{ address }}",
-                            "address": "{{ address }}",
-                        },
-                    ],
+                    "group_{{ grp_no|string }}": {
+                        "ipv6": {"addresses": ["{{ address }}"]},
+                    },
                 },
             },
         },
@@ -362,16 +323,15 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
             "name": "mac_address",
             "getval": re.compile(
                 r"""
-                \s+standby\s*(?P<group_no>\d+)?\s*mac-address\s(?P<mac_address>\S+)
+                \s+standby\s*(?P<grp_no>\d+)?\s*mac-address\s(?P<mac_address>\S+)
                 $""", re.VERBOSE,
             ),
-            "setval": "standby {{ mac_address.group_no|string if mac_address.group_no is defined else '' }} mac-address {{ mac_address.mac_address }}",
+            "setval": "standby {{ group_no|string if group_no is defined else '' }} mac-address {{ mac_address }}",
             "result": {
                 "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
+                    "group_{{ grp_no|string }}": {
                         "mac_address": "{{ mac_address }}",
-                    }],
+                    },
                 },
             },
         },
@@ -379,93 +339,52 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
             "name": "group_name",
             "getval": re.compile(
                 r"""
-                \s+standby\s*(?P<group_no>\d+)?\s*name\s+(?P<group_name>.+)$
+                \s+standby\s*(?P<grp_no>\d+)?\s*name\s+(?P<group_name>.+)$
                 """, re.VERBOSE,
             ),
-            "setval": "standby {{ group_name.group_no|string if group_name.group_no is defined else '' }} name {{ group_name.group_name }}",
+            "setval": "standby {{ group_no|string if group_no is defined else '' }} name {{ group_name }}",
             "result": {
                 "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
+                    "group_{{ grp_no|string }}": {
                         "group_name": "{{ group_name }}",
-                    }],
+                    },
                 },
             },
         },
         {
-            "name": "authentication.plain_text",
+            "name": "authentication",
             "getval": re.compile(
                 r"""
-                ^\s*standby\s+(?P<group_no>\d+)\s+authentication(?:\s+text)?\s+(?P<password_text>\S+)
-                $""",
-                re.VERBOSE,
+                \s*standby\s(?P<grp_no>\d+)
+                \s*authentication
+                (\smd5\skey-chain\s(?P<key_chain>\S+)|
+                \smd5\skey-string\s(?:(?P<encryption>\d+)\s)?(?P<key_string>\S+)|
+                \s(?P<password_text>\S+))?
+                (\stimeout\s(?P<timeout>\d+))?
+                $""", re.VERBOSE,
             ),
-            "setval": (
-                "{% if authentication.advertisement.key_string is not defined%}"
-                "standby {{ authentication.group_no|string }} "
-                "authentication text {{ authentication.advertisement.password_text }}"
-                "{% endif %}"
-            ),
-            "compval": "authentication",
+            "setval": "standby"
+            "{{ ' ' + group_no|string if group_no is defined else ''}}"
+            " authentication"
+            "{{ (' ' + authentication.password_text|string) "
+            "if authentication.password_text is defined else '' }}"
+            "{{ (' md5 key-chain ' + authentication.key_chain|string) "
+            "if authentication.key_chain is defined else '' }}"
+            "{{ (' md5 key-string ' + authentication.encryption|string + ' ' + authentication.key_string) "
+            "if authentication.key_string is defined and authentication.encryption is defined "
+            "else (' md5 key-string ' + authentication.key_string) "
+            "if authentication.key_string is defined else '' }}",
             "result": {
                 "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
+                    "group_{{ grp_no|string }}": {
                         "authentication": {
-                            "advertisement": {
-                                "password_text": "{{ password_text }}",
-                            },
+                            "key_chain": "{{ key_chain }}",
+                            "key_string": "'{{ key_string }}'",
+                            "encryption": "{{ encryption|string }}",
+                            "password_text": "{{ password_text }}",
+                            "time_out": "{{ timeout }}",
                         },
-                    }],
-                },
-            },
-        },
-        {
-            "name": "authentication.md5",
-            "getval": re.compile(
-                r"""
-                ^\s*standby\s+(?P<group_no>\d+)\s+authentication\s+md5\s+
-                (?:
-                    key-chain\s+(?P<key_chain>\S+)
-                    |
-                    key-string\s+(?:(?P<encryption>\d+)\s+)?(?P<password_text>\S+)
-                    (?:\s+timeout\s+(?P<time_out>\d+))?
-                )
-                $""",
-                re.VERBOSE,
-            ),
-            "compval": "authentication",
-            "setval": (
-                "{% if authentication.advertisement.key_string is defined or authentication.advertisement.key_chain is defined %}"
-                "standby {{ authentication.group_no|string }} authentication md5 "
-                "{% if authentication.advertisement.key_chain is defined %}"
-                "key-chain {{ authentication.advertisement.key_chain }}"
-                "{% else %}"
-                "key-string "
-                "{% if authentication.advertisement.encryption is defined %}"
-                "{{ authentication.advertisement.encryption }} "
-                "{% endif %}"
-                "{{ authentication.advertisement.password_text }} "
-                "{% if authentication.advertisement.time_out is defined %}"
-                "timeout {{ authentication.advertisement.time_out|string }}"
-                "{% endif %}"
-                "{% endif %}"
-                "{% endif %}"
-            ),
-            "result": {
-                "{{ name }}": {
-                    "standby_groups": [{
-                        "group_no": "{{ group_no }}",
-                        "authentication": {
-                            "advertisement": {
-                                "key_chain": "{{ key_chain }}",
-                                "key_string": "{{ True if key_chain is not defined else None}}",
-                                "password_text": "{{ password_text }}",
-                                "encryption": "{{ encryption }}",
-                                "time_out": "{{ time_out }}",
-                            },
-                        },
-                    }],
+                    },
                 },
             },
         },
@@ -490,83 +409,33 @@ class Hsrp_interfacesTemplate(NetworkTemplate):
             },
         },
         {
-            "name": "redirect.md5.key_chain",
+            "name": "redirect.advertisement.authentication",
             "getval": re.compile(
                 r"""
-                \s+standby\sredirect\sadvertisement\sauthentication\smd5\skey-chain\s(?P<key_chain>\S+)
+                \s*standby\sredirect
+                \sadvertisement\sauthentication
+                (\smd5\skey-chain\s(?P<key_chain>\S+)|
+                \smd5\skey-string\s(?:(?P<encryption>\d+)\s)?(?P<key_string>\S+))?
+                (\stimeout\s(?P<timeout>\d+))?
                 $""", re.VERBOSE,
             ),
-            "compval": "redirect",
-            "setval": "standby redirect advertisement authentication md5 key-chain {{ redirect.advertisement.authentication.key_chain }}",
+            "setval": "standby redirect advertisement authentication"
+            "{{ (' md5 key-chain ' + redirect.advertisement.authentication.key_chain|string) "
+            "if redirect.advertisement.authentication.key_chain is defined else '' }}"
+            "{{ (' md5 key-string ' + "
+            "(redirect.advertisement.authentication.encryption|string + ' ') "
+            "if redirect.advertisement.authentication.encryption is defined else '' "
+            "+ redirect.advertisement.authentication.key_string|string) "
+            "if redirect.advertisement.authentication.key_string is defined else '' }}",
             "result": {
                 "{{ name }}": {
                     "redirect": {
                         "advertisement": {
                             "authentication": {
                                 "key_chain": "{{ key_chain }}",
-                            },
-                        },
-                    },
-                },
-            },
-        },
-        {
-            "name": "redirect.md5.key_string",
-            "getval": re.compile(
-                r"""
-                \s*standby\s+
-                redirect\s+
-                advertisement\s+
-                authentication\s+md5\s+
-                key-string\s+
-                (?P<encryption>0|7)\s+
-                (?P<password_text>\S+)\s*
-                (?:\s*timeout\s+(?P<time_out>\d+))?
-                $""", re.VERBOSE,
-            ),
-            "compval": "redirect",
-            "setval": "standby redirect advertisement authentication md5 key-string {{ redirect.advertisement.authentication.encryption|string }} "
-            "{{ redirect.advertisement.authentication.password_text }} "
-            "{{ 'timeout ' + redirect.advertisement.authentication.time_out|string if redirect.advertisement.authentication.time_out is defined else '' }}",
-            "result": {
-                "{{ name }}": {
-                    "redirect": {
-                        "advertisement": {
-                            "authentication": {
+                                "key_string": "'{{ key_string }}'",
                                 "encryption": "{{ encryption }}",
-                                "key_string": "{{ True }}",
-                                "password_text": "{{ password_text }}",
-                                "time_out": "{{ time_out }}",
-                            },
-                        },
-                    },
-                },
-            },
-        },
-        {
-            "name": "redirect.md5.key_string_without_encryption",
-            "getval": re.compile(
-                r"""
-                \s*standby\s+
-                redirect\s+
-                advertisement\s+
-                authentication\s+md5\s+
-                key-string\s+
-                (?P<password_text>\S+)\s*
-                (?:\s*timeout\s+(?P<time_out>\d+))?
-                $""", re.VERBOSE,
-            ),
-            "compval": "redirect",
-            "setval": "standby redirect advertisement authentication md5 key-string {{ redirect.advertisement.authentication.password_text }} "
-            "{{ 'timeout ' + redirect.advertisement.authentication.time_out|string if redirect.advertisement.authentication.time_out is defined else '' }}",
-            "result": {
-                "{{ name }}": {
-                    "redirect": {
-                        "advertisement": {
-                            "authentication": {
-                                "key_string": "{{ True }}",
-                                "password_text": "{{ password_text }}",
-                                "time_out": "{{ time_out }}",
+                                "time_out": "{{ timeout }}",
                             },
                         },
                     },
