@@ -6,10 +6,14 @@
 # dependencies = ["nox>=2025.02.09", "antsibull-nox"]
 # ///
 
+import os
 import sys
 
 import nox
 
+# Whether the noxfile is running in CI:
+IN_CI = os.environ.get("CI") == "true"
+
 
 try:
     import antsibull_nox
@@ -32,6 +36,23 @@ def botmeta(session: nox.Session) -> None:
     session.run("python", "tests/sanity/extra/botmeta.py")
 
 
+@nox.session(name="ansible-output", default=False)
+def ansible_output(session: nox.Session) -> None:
+    session.install(
+        "ansible-core",
+        "antsibull-docs",
+        # Needed libs for some code blocks:
+        "jc",
+        "hashids",
+        # Tools for post-processing
+        "ruamel.yaml",  # used by docs/docsite/reformat-yaml.py
+    )
+    args = []
+    if IN_CI:
+        args.append("--check")
+    session.run("antsibull-docs", "ansible-output", *args, *session.posargs)
+
+
 # Allow to run the noxfile with `python noxfile.py`, `pipx run noxfile.py`, or similar.
 # Requires nox >= 2025.02.09
 if __name__ == "__main__":
