@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # This module is proudly sponsored by CGI (www.cgi.com) and
 # KPN (www.kpn.com).
@@ -7,8 +6,7 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
 DOCUMENTATION = r"""
@@ -151,75 +149,62 @@ class icinga2_api:
     def __init__(self, module):
         self.module = module
 
-    def call_url(self, path, data='', method='GET'):
+    def call_url(self, path, data="", method="GET"):
         headers = {
-            'Accept': 'application/json',
-            'X-HTTP-Method-Override': method,
+            "Accept": "application/json",
+            "X-HTTP-Method-Override": method,
         }
-        url = self.module.params.get("url") + "/" + path
-        rsp, info = fetch_url(module=self.module, url=url, data=data, headers=headers, method=method, use_proxy=self.module.params['use_proxy'])
-        body = ''
+        url = f"{self.module.params.get('url')}/{path}"
+        rsp, info = fetch_url(
+            module=self.module,
+            url=url,
+            data=data,
+            headers=headers,
+            method=method,
+            use_proxy=self.module.params["use_proxy"],
+        )
+        body = ""
         if rsp:
             body = json.loads(rsp.read())
-        if info['status'] >= 400:
-            body = info['body']
-        return {'code': info['status'], 'data': body}
+        if info["status"] >= 400:
+            body = info["body"]
+        return {"code": info["status"], "data": body}
 
     def check_connection(self):
-        ret = self.call_url('v1/status')
-        if ret['code'] == 200:
-            return True
-        return False
+        ret = self.call_url("v1/status")
+        return ret["code"] == 200
 
     def exists(self, hostname):
         data = {
-            "filter": "match(\"" + hostname + "\", host.name)",
+            "filter": f'match("{hostname}", host.name)',
         }
-        ret = self.call_url(
-            path="v1/objects/hosts",
-            data=self.module.jsonify(data)
-        )
-        if ret['code'] == 200:
-            if len(ret['data']['results']) == 1:
+        ret = self.call_url(path="v1/objects/hosts", data=self.module.jsonify(data))
+        if ret["code"] == 200:
+            if len(ret["data"]["results"]) == 1:
                 return True
         return False
 
     def create(self, hostname, data):
-        ret = self.call_url(
-            path="v1/objects/hosts/" + hostname,
-            data=self.module.jsonify(data),
-            method="PUT"
-        )
+        ret = self.call_url(path=f"v1/objects/hosts/{hostname}", data=self.module.jsonify(data), method="PUT")
         return ret
 
     def delete(self, hostname):
         data = {"cascade": 1}
-        ret = self.call_url(
-            path="v1/objects/hosts/" + hostname,
-            data=self.module.jsonify(data),
-            method="DELETE"
-        )
+        ret = self.call_url(path=f"v1/objects/hosts/{hostname}", data=self.module.jsonify(data), method="DELETE")
         return ret
 
     def modify(self, hostname, data):
-        ret = self.call_url(
-            path="v1/objects/hosts/" + hostname,
-            data=self.module.jsonify(data),
-            method="POST"
-        )
+        ret = self.call_url(path=f"v1/objects/hosts/{hostname}", data=self.module.jsonify(data), method="POST")
         return ret
 
     def diff(self, hostname, data):
-        ret = self.call_url(
-            path="v1/objects/hosts/" + hostname,
-            method="GET"
-        )
+        ret = self.call_url(path=f"v1/objects/hosts/{hostname}", method="GET")
         changed = False
-        ic_data = ret['data']['results'][0]
-        for key in data['attrs']:
-            if key not in ic_data['attrs'].keys():
+        ic_data = ret["data"]["results"][0]
+        for key in data["attrs"]:
+            if key not in ic_data["attrs"].keys():
                 changed = True
-            elif data['attrs'][key] != ic_data['attrs'][key]:
+            elif data["attrs"][key] != ic_data["attrs"][key]:
                 changed = True
         return changed
 
@@ -233,20 +218,17 @@ def main():
     # add our own arguments
     argument_spec.update(
         state=dict(default="present", choices=["absent", "present"]),
-        name=dict(required=True, aliases=['host']),
+        name=dict(required=True, aliases=["host"]),
         zone=dict(),
-        template=dict(default=None),
+        template=dict(),
         check_command=dict(default="hostalive"),
-        display_name=dict(default=None),
+        display_name=dict(),
         ip=dict(),
-        variables=dict(type='dict', default=None),
+        variables=dict(type="dict"),
     )
 
     # Define the main module
-    module = AnsibleModule(
-        argument_spec=argument_spec,
-        supports_check_mode=True
-    )
+    module = AnsibleModule(argument_spec=argument_spec, supports_check_mode=True)
 
     state = module.params["state"]
     name = module.params["name"]
@@ -265,19 +247,19 @@ def main():
         icinga = icinga2_api(module=module)
         icinga.check_connection()
     except Exception as e:
-        module.fail_json(msg="unable to connect to Icinga. Exception message: %s" % (e))
+        module.fail_json(msg=f"unable to connect to Icinga. Exception message: {e}")
 
     data = {
-        'templates': template,
-        'attrs': {
-            'address': ip,
-            'display_name': display_name,
-            'check_command': check_command,
-            'zone': zone,
-            'vars.made_by': "ansible"
-        }
+        "templates": template,
+        "attrs": {
+            "address": ip,
+            "display_name": display_name,
+            "check_command": check_command,
+            "zone": zone,
+            "vars.made_by": "ansible",
+        },
     }
-    data['attrs'].update({'vars.' + key: value for key, value in variables.items()})
+    data["attrs"].update({f"vars.{key}": value for key, value in variables.items()})
 
     changed = False
     if icinga.exists(name):
@@ -287,26 +269,26 @@ def main():
             else:
                 try:
                     ret = icinga.delete(name)
-                    if ret['code'] == 200:
+                    if ret["code"] == 200:
                         changed = True
                     else:
-                        module.fail_json(msg="bad return code (%s) deleting host: '%s'" % (ret['code'], ret['data']))
+                        module.fail_json(msg=f"bad return code ({ret['code']}) deleting host: '{ret['data']}'")
                 except Exception as e:
-                    module.fail_json(msg="exception deleting host: " + str(e))
+                    module.fail_json(msg=f"exception deleting host: {e}")
 
         elif icinga.diff(name, data):
             if module.check_mode:
                 module.exit_json(changed=False, name=name, data=data)
 
             # Template attribute is not allowed in modification
-            del data['templates']
+            del data["templates"]
 
             ret = icinga.modify(name, data)
 
-            if ret['code'] == 200:
+            if ret["code"] == 200:
                 changed = True
             else:
-                module.fail_json(msg="bad return code (%s) modifying host: '%s'" % (ret['code'], ret['data']))
+                module.fail_json(msg=f"bad return code ({ret['code']}) modifying host: '{ret['data']}'")
 
     else:
         if state == "present":
@@ -315,16 +297,16 @@ def main():
             else:
                 try:
                     ret = icinga.create(name, data)
-                    if ret['code'] == 200:
+                    if ret["code"] == 200:
                         changed = True
                     else:
-                        module.fail_json(msg="bad return code (%s) creating host: '%s'" % (ret['code'], ret['data']))
+                        module.fail_json(msg=f"bad return code ({ret['code']}) creating host: '{ret['data']}'")
                 except Exception as e:
-                    module.fail_json(msg="exception creating host: " + str(e))
+                    module.fail_json(msg=f"exception creating host: {e}")
 
     module.exit_json(changed=changed, name=name, data=data)
 
 
 # import module snippets
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
