@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright (c) 2014, Steve Smith <ssmith@atlassian.com>
 # Atlassian open-source approval reference OSR-76.
@@ -11,8 +10,7 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
 DOCUMENTATION = r"""
@@ -74,36 +72,30 @@ options:
 
   project:
     type: str
-    required: false
     description:
       - The project for this operation. Required for issue creation.
   summary:
     type: str
-    required: false
     description:
       - The issue summary, where appropriate.
       - Note that JIRA may not allow changing field values on specific transitions or states.
   description:
     type: str
-    required: false
     description:
       - The issue description, where appropriate.
       - Note that JIRA may not allow changing field values on specific transitions or states.
   issuetype:
     type: str
-    required: false
     description:
       - The issue type, for issue creation.
   issue:
     type: str
-    required: false
     description:
       - An existing issue key to operate on.
     aliases: ['ticket']
 
   comment:
     type: str
-    required: false
     description:
       - The comment text to add.
       - Note that JIRA may not allow changing field values on specific transitions or states.
@@ -130,20 +122,17 @@ options:
 
   status:
     type: str
-    required: false
     description:
       - Only used when O(operation) is V(transition), and a bit of a misnomer, it actually refers to the transition name.
       - This is mutually exclusive with O(status_id).
   status_id:
     type: str
-    required: false
     description:
       - Only used when O(operation) is V(transition), and refers to the transition ID.
       - This is mutually exclusive with O(status).
     version_added: 10.3.0
   assignee:
     type: str
-    required: false
     description:
       - Sets the assignee when O(operation) is V(create), V(transition), or V(edit).
       - Recent versions of JIRA no longer accept a user name as a user identifier. In that case, use O(account_id) instead.
@@ -157,22 +146,18 @@ options:
 
   linktype:
     type: str
-    required: false
     description:
       - Set type of link, when action 'link' selected.
   inwardissue:
     type: str
-    required: false
     description:
       - Set issue from which link is created.
   outwardissue:
     type: str
-    required: false
     description:
       - Set issue to which link is created.
   fields:
     type: dict
-    required: false
     description:
       - This is a free-form data structure that can contain arbitrary data. This is passed directly to the JIRA REST API (possibly
         after merging with other required data, as when passed to create). See examples for more information, and the JIRA
@@ -182,14 +167,12 @@ options:
       - Note that JIRA may not allow changing field values on specific transitions or states.
     default: {}
   jql:
-    required: false
     description:
       - Query JIRA in JQL Syntax, for example V("CMDB Hostname" = test.example.com).
     type: str
     version_added: '0.2.0'
 
   maxresults:
-    required: false
     description:
       - Limit the result of O(operation=search). If no value is specified, the default JIRA limit is used.
       - Used when O(operation=search) only, ignored otherwise.
@@ -198,13 +181,11 @@ options:
 
   timeout:
     type: float
-    required: false
     description:
       - Set timeout, in seconds, on requests to JIRA API.
     default: 10
 
   validate_certs:
-    required: false
     description:
       - Require valid SSL certificates (set to V(false) if you would like to use self-signed certificates).
     default: true
@@ -484,9 +465,9 @@ import os
 import random
 import string
 import traceback
+from urllib.request import pathname2url
 
 from ansible_collections.community.general.plugins.module_utils.module_helper import StateModuleHelper, cause_changes
-from ansible.module_utils.six.moves.urllib.request import pathname2url
 from ansible.module_utils.common.text.converters import to_text, to_bytes, to_native
 from ansible.module_utils.urls import fetch_url
 
@@ -494,139 +475,171 @@ from ansible.module_utils.urls import fetch_url
 class JIRA(StateModuleHelper):
     module = dict(
         argument_spec=dict(
-            attachment=dict(type='dict', options=dict(
-                content=dict(type='str'),
-                filename=dict(type='path', required=True),
-                mimetype=dict(type='str')
-            )),
-            uri=dict(type='str', required=True),
-            operation=dict(
-                type='str',
-                choices=['attach', 'create', 'comment', 'edit', 'update', 'fetch', 'transition', 'link', 'search', 'worklog'],
-                aliases=['command'], required=True
+            attachment=dict(
+                type="dict",
+                options=dict(
+                    content=dict(type="str"), filename=dict(type="path", required=True), mimetype=dict(type="str")
+                ),
             ),
-            username=dict(type='str'),
-            password=dict(type='str', no_log=True),
-            token=dict(type='str', no_log=True),
-            client_cert=dict(type='path'),
-            client_key=dict(type='path'),
-            project=dict(type='str', ),
-            summary=dict(type='str', ),
-            description=dict(type='str', ),
-            issuetype=dict(type='str', ),
-            issue=dict(type='str', aliases=['ticket']),
-            comment=dict(type='str', ),
-            comment_visibility=dict(type='dict', options=dict(
-                type=dict(type='str', choices=['group', 'role'], required=True),
-                value=dict(type='str', required=True)
-            )),
-            status=dict(type='str', ),
-            status_id=dict(type='str', ),
-            assignee=dict(type='str', ),
-            fields=dict(default={}, type='dict'),
-            linktype=dict(type='str', ),
-            inwardissue=dict(type='str', ),
-            outwardissue=dict(type='str', ),
-            jql=dict(type='str', ),
-            maxresults=dict(type='int'),
-            timeout=dict(type='float', default=10),
-            validate_certs=dict(default=True, type='bool'),
-            account_id=dict(type='str'),
+            uri=dict(type="str", required=True),
+            operation=dict(
+                type="str",
+                choices=[
+                    "attach",
+                    "create",
+                    "comment",
+                    "edit",
+                    "update",
+                    "fetch",
+                    "transition",
+                    "link",
+                    "search",
+                    "worklog",
+                ],
+                aliases=["command"],
+                required=True,
+            ),
+            username=dict(type="str"),
+            password=dict(type="str", no_log=True),
+            token=dict(type="str", no_log=True),
+            client_cert=dict(type="path"),
+            client_key=dict(type="path"),
+            project=dict(
+                type="str",
+            ),
+            summary=dict(
+                type="str",
+            ),
+            description=dict(
+                type="str",
+            ),
+            issuetype=dict(
+                type="str",
+            ),
+            issue=dict(type="str", aliases=["ticket"]),
+            comment=dict(
+                type="str",
+            ),
+            comment_visibility=dict(
+                type="dict",
+                options=dict(
+                    type=dict(type="str", choices=["group", "role"], required=True),
+                    value=dict(type="str", required=True),
+                ),
+            ),
+            status=dict(
+                type="str",
+            ),
+            status_id=dict(
+                type="str",
+            ),
+            assignee=dict(
+                type="str",
+            ),
+            fields=dict(default={}, type="dict"),
+            linktype=dict(
+                type="str",
+            ),
+            inwardissue=dict(
+                type="str",
+            ),
+            outwardissue=dict(
+                type="str",
+            ),
+            jql=dict(
+                type="str",
+            ),
+            maxresults=dict(type="int"),
+            timeout=dict(type="float", default=10),
+            validate_certs=dict(default=True, type="bool"),
+            account_id=dict(type="str"),
         ),
         mutually_exclusive=[
-            ['username', 'token'],
-            ['password', 'token'],
-            ['assignee', 'account_id'],
-            ['status', 'status_id']
-        ],
-        required_together=[
-            ['username', 'password'],
-            ['client_cert', 'client_key']
+            ["username", "token"],
+            ["password", "token"],
+            ["assignee", "account_id"],
+            ["status", "status_id"],
         ],
+        required_together=[["username", "password"], ["client_cert", "client_key"]],
         required_one_of=[
-            ['username', 'token'],
+            ["username", "token"],
         ],
         required_if=(
-            ('operation', 'attach', ['issue', 'attachment']),
-            ('operation', 'create', ['project', 'issuetype', 'summary']),
-            ('operation', 'comment', ['issue', 'comment']),
-            ('operation', 'workflow', ['issue', 'comment']),
-            ('operation', 'fetch', ['issue']),
-            ('operation', 'transition', ['issue']),
-            ('operation', 'transition', ['status', 'status_id'], True),
-            ('operation', 'link', ['linktype', 'inwardissue', 'outwardissue']),
-            ('operation', 'search', ['jql']),
+            ("operation", "attach", ["issue", "attachment"]),
+            ("operation", "create", ["project", "issuetype", "summary"]),
+            ("operation", "comment", ["issue", "comment"]),
+            ("operation", "workflow", ["issue", "comment"]),
+            ("operation", "fetch", ["issue"]),
+            ("operation", "transition", ["issue"]),
+            ("operation", "transition", ["status", "status_id"], True),
+            ("operation", "link", ["linktype", "inwardissue", "outwardissue"]),
+            ("operation", "search", ["jql"]),
         ),
-        supports_check_mode=False
+        supports_check_mode=False,
     )
-    state_param = 'operation'
+    state_param = "operation"
 
     def __init_module__(self):
         if self.vars.fields is None:
             self.vars.fields = {}
         if self.vars.assignee:
-            self.vars.fields['assignee'] = {'name': self.vars.assignee}
+            self.vars.fields["assignee"] = {"name": self.vars.assignee}
         if self.vars.account_id:
-            self.vars.fields['assignee'] = {'accountId': self.vars.account_id}
-        self.vars.uri = self.vars.uri.strip('/')
-        self.vars.set('restbase', self.vars.uri + '/rest/api/2')
+            self.vars.fields["assignee"] = {"accountId": self.vars.account_id}
+        self.vars.uri = self.vars.uri.strip("/")
+        self.vars.set("restbase", f"{self.vars.uri}/rest/api/2")
 
     @cause_changes(when="success")
     def operation_create(self):
         createfields = {
-            'project': {'key': self.vars.project},
-            'summary': self.vars.summary,
-            'issuetype': {'name': self.vars.issuetype}}
+            "project": {"key": self.vars.project},
+            "summary": self.vars.summary,
+            "issuetype": {"name": self.vars.issuetype},
+        }
 
         if self.vars.description:
-            createfields['description'] = self.vars.description
+            createfields["description"] = self.vars.description
 
         # Merge in any additional or overridden fields
         if self.vars.fields:
             createfields.update(self.vars.fields)
 
-        data = {'fields': createfields}
-        url = self.vars.restbase + '/issue/'
+        data = {"fields": createfields}
+        url = f"{self.vars.restbase}/issue/"
         self.vars.meta = self.post(url, data)
 
     @cause_changes(when="success")
     def operation_comment(self):
-        data = {
-            'body': self.vars.comment
-        }
+        data = {"body": self.vars.comment}
         # if comment_visibility is specified restrict visibility
         if self.vars.comment_visibility is not None:
-            data['visibility'] = self.vars.comment_visibility
+            data["visibility"] = self.vars.comment_visibility
 
         # Use 'fields' to merge in any additional data
         if self.vars.fields:
             data.update(self.vars.fields)
 
-        url = self.vars.restbase + '/issue/' + self.vars.issue + '/comment'
+        url = f"{self.vars.restbase}/issue/{self.vars.issue}/comment"
         self.vars.meta = self.post(url, data)
 
     @cause_changes(when="success")
     def operation_worklog(self):
-        data = {
-            'comment': self.vars.comment
-        }
+        data = {"comment": self.vars.comment}
         # if comment_visibility is specified restrict visibility
         if self.vars.comment_visibility is not None:
-            data['visibility'] = self.vars.comment_visibility
+            data["visibility"] = self.vars.comment_visibility
 
         # Use 'fields' to merge in any additional data
         if self.vars.fields:
             data.update(self.vars.fields)
 
-        url = self.vars.restbase + '/issue/' + self.vars.issue + '/worklog'
+        url = f"{self.vars.restbase}/issue/{self.vars.issue}/worklog"
         self.vars.meta = self.post(url, data)
 
     @cause_changes(when="success")
     def operation_edit(self):
-        data = {
-            'fields': self.vars.fields
-        }
-        url = self.vars.restbase + '/issue/' + self.vars.issue
+        data = {"fields": self.vars.fields}
+        url = f"{self.vars.restbase}/issue/{self.vars.issue}"
         self.vars.meta = self.put(url, data)
 
     @cause_changes(when="success")
@@ -634,27 +647,27 @@ class JIRA(StateModuleHelper):
         data = {
             "update": self.vars.fields,
         }
-        url = self.vars.restbase + '/issue/' + self.vars.issue
+        url = f"{self.vars.restbase}/issue/{self.vars.issue}"
         self.vars.meta = self.put(url, data)
 
     def operation_fetch(self):
-        url = self.vars.restbase + '/issue/' + self.vars.issue
+        url = f"{self.vars.restbase}/issue/{self.vars.issue}"
         self.vars.meta = self.get(url)
 
     def operation_search(self):
-        url = self.vars.restbase + '/search?jql=' + pathname2url(self.vars.jql)
+        url = f"{self.vars.restbase}/search?jql={pathname2url(self.vars.jql)}"
         if self.vars.fields:
             fields = self.vars.fields.keys()
-            url = url + '&fields=' + '&fields='.join([pathname2url(f) for f in fields])
+            url = f"{url}&fields={'&fields='.join([pathname2url(f) for f in fields])}"
         if self.vars.maxresults:
-            url = url + '&maxResults=' + str(self.vars.maxresults)
+            url = f"{url}&maxResults={self.vars.maxresults}"
 
         self.vars.meta = self.get(url)
 
     @cause_changes(when="success")
     def operation_transition(self):
         # Find the transition id
-        turl = self.vars.restbase + '/issue/' + self.vars.issue + "/transitions"
+        turl = f"{self.vars.restbase}/issue/{self.vars.issue}/transitions"
         tmeta = self.get(turl)
 
         tid = None
@@ -665,64 +678,65 @@ class JIRA(StateModuleHelper):
         elif self.vars.status_id is not None:
             tid = self.vars.status_id.strip()
 
-        for t in tmeta['transitions']:
+        for t in tmeta["transitions"]:
             if target is not None:
-                if t['name'] == target:
-                    tid = t['id']
+                if t["name"] == target:
+                    tid = t["id"]
                     break
             else:
-                if tid == t['id']:
+                if tid == t["id"]:
                     break
         else:
             if target is not None:
-                raise ValueError("Failed find valid transition for '%s'" % target)
+                raise ValueError(f"Failed find valid transition for '{target}'")
             else:
-                raise ValueError("Failed find valid transition for ID '%s'" % tid)
+                raise ValueError(f"Failed find valid transition for ID '{tid}'")
 
         fields = dict(self.vars.fields)
         if self.vars.summary is not None:
-            fields.update({'summary': self.vars.summary})
+            fields.update({"summary": self.vars.summary})
         if self.vars.description is not None:
-            fields.update({'description': self.vars.description})
+            fields.update({"description": self.vars.description})
 
         # Perform it
-        data = {'transition': {"id": tid},
-                'fields': fields}
+        data = {"transition": {"id": tid}, "fields": fields}
         if self.vars.comment is not None:
-            data.update({"update": {
-                "comment": [{
-                    "add": {"body": self.vars.comment}
-                }],
-            }})
-        url = self.vars.restbase + '/issue/' + self.vars.issue + "/transitions"
+            data.update(
+                {
+                    "update": {
+                        "comment": [{"add": {"body": self.vars.comment}}],
+                    }
+                }
+            )
+        url = f"{self.vars.restbase}/issue/{self.vars.issue}/transitions"
         self.vars.meta = self.post(url, data)
 
     @cause_changes(when="success")
     def operation_link(self):
         data = {
-            'type': {'name': self.vars.linktype},
-            'inwardIssue': {'key': self.vars.inwardissue},
-            'outwardIssue': {'key': self.vars.outwardissue},
+            "type": {"name": self.vars.linktype},
+            "inwardIssue": {"key": self.vars.inwardissue},
+            "outwardIssue": {"key": self.vars.outwardissue},
         }
-        url = self.vars.restbase + '/issueLink/'
+        url = f"{self.vars.restbase}/issueLink/"
         self.vars.meta = self.post(url, data)
 
     @cause_changes(when="success")
     def operation_attach(self):
         v = self.vars
-        filename = v.attachment.get('filename')
-        content = v.attachment.get('content')
+        filename = v.attachment.get("filename")
+        content = v.attachment.get("content")
 
         if not any((filename, content)):
-            raise ValueError('at least one of filename or content must be provided')
-        mime = v.attachment.get('mimetype')
+            raise ValueError("at least one of filename or content must be provided")
+        mime = v.attachment.get("mimetype")
 
         if not os.path.isfile(filename):
-            raise ValueError('The provided filename does not exist: %s' % filename)
+            raise ValueError(f"The provided filename does not exist: {filename}")
 
         content_type, data = self._prepare_attachment(filename, content, mime)
 
-        url = v.restbase + '/issue/' + v.issue + '/attachments'
+        url = f"{v.restbase}/issue/{v.issue}/attachments"
         return True, self.post(
             url, data, content_type=content_type, additional_headers={"X-Atlassian-Token": "no-check"}
         )
@@ -745,48 +759,38 @@ class JIRA(StateModuleHelper):
             return s.replace('"', '\\"')
 
         boundary = "".join(random.choice(string.digits + string.ascii_letters) for dummy in range(30))
-        name = to_native(os.path.basename(filename))
+        name = os.path.basename(filename)
 
         if not mime_type:
             try:
-                mime_type = mimetypes.guess_type(filename or '', strict=False)[0] or 'application/octet-stream'
+                mime_type = mimetypes.guess_type(filename or "", strict=False)[0] or "application/octet-stream"
             except Exception:
-                mime_type = 'application/octet-stream'
-        main_type, sep, sub_type = mime_type.partition('/')
+                mime_type = "application/octet-stream"
+        main_type, sep, sub_type = mime_type.partition("/")
 
         if not content and filename:
-            with open(to_bytes(filename, errors='surrogate_or_strict'), 'rb') as f:
+            with open(to_bytes(filename, errors="surrogate_or_strict"), "rb") as f:
                 content = f.read()
         else:
             try:
                 content = base64.b64decode(content)
             except binascii.Error as e:
-                raise Exception("Unable to base64 decode file content: %s" % e)
+                raise Exception(f"Unable to base64 decode file content: {e}") from e
 
         lines = [
-            "--{0}".format(boundary),
-            'Content-Disposition: form-data; name="file"; filename={0}'.format(escape_quotes(name)),
-            "Content-Type: {0}".format("{0}/{1}".format(main_type, sub_type)),
-            '',
+            f"--{boundary}",
+            f'Content-Disposition: form-data; name="file"; filename={escape_quotes(name)}',
+            f"Content-Type: {main_type}/{sub_type}",
+            "",
             to_text(content),
-            "--{0}--".format(boundary),
-            ""
+            f"--{boundary}--",
+            "",
         ]
 
-        return (
-            "multipart/form-data; boundary={0}".format(boundary),
-            "\r\n".join(lines)
-        )
+        return (f"multipart/form-data; boundary={boundary}", "\r\n".join(lines))
 
-    def request(
-            self,
-            url,
-            data=None,
-            method=None,
-            content_type='application/json',
-            additional_headers=None
-    ):
-        if data and content_type == 'application/json':
+    def request(self, url, data=None, method=None, content_type="application/json", additional_headers=None):
+        if data and content_type == "application/json":
             data = json.dumps(data)
 
         headers = {}
@@ -802,58 +806,58 @@ class JIRA(StateModuleHelper):
         # the requests as authorized for this user.
 
         if self.vars.token is not None:
-            headers.update({
-                "Content-Type": content_type,
-                "Authorization": "Bearer %s" % self.vars.token,
-            })
+            headers.update(
+                {
+                    "Content-Type": content_type,
+                    "Authorization": f"Bearer {self.vars.token}",
+                }
+            )
         else:
-            auth = to_text(base64.b64encode(to_bytes('{0}:{1}'.format(self.vars.username, self.vars.password),
-                                                     errors='surrogate_or_strict')))
-            headers.update({
-                "Content-Type": content_type,
-                "Authorization": "Basic %s" % auth,
-            })
+            auth = to_text(
+                base64.b64encode(to_bytes(f"{self.vars.username}:{self.vars.password}", errors="surrogate_or_strict"))
+            )
+            headers.update(
+                {
+                    "Content-Type": content_type,
+                    "Authorization": f"Basic {auth}",
+                }
+            )
 
         response, info = fetch_url(
             self.module, url, data=data, method=method, timeout=self.vars.timeout, headers=headers
         )
 
-        if info['status'] not in (200, 201, 204):
+        if info["status"] not in (200, 201, 204):
             error = None
             try:
-                error = json.loads(info['body'])
+                error = json.loads(info["body"])
             except Exception:
-                msg = 'The request "{method} {url}" returned the unexpected status code {status} {msg}\n{body}'.format(
-                    status=info['status'],
-                    msg=info['msg'],
-                    body=info.get('body'),
-                    url=url,
-                    method=method,
-                )
-                self.module.fail_json(msg=to_native(msg), exception=traceback.format_exc())
+                msg = f'The request "{method} {url}" returned the unexpected status code {info["status"]} {info["msg"]}\n{info.get("body")}'
+                self.module.fail_json(msg=msg, exception=traceback.format_exc())
             if error:
                 msg = []
-                for key in ('errorMessages', 'errors'):
+                for key in ("errorMessages", "errors"):
                     if error.get(key):
-                        msg.append(to_native(error[key]))
+                        msg.append(str(error[key]))
                 if msg:
-                    self.module.fail_json(msg=', '.join(msg))
-                self.module.fail_json(msg=to_native(error))
+                    self.module.fail_json(msg=", ".join(msg))
+                self.module.fail_json(msg=f"{error}")
             # Fallback print body, if it can't be decoded
-            self.module.fail_json(msg=to_native(info['body']))
+            self.module.fail_json(msg=to_native(info["body"]))
 
         body = response.read()
 
         if body:
-            return json.loads(to_text(body, errors='surrogate_or_strict'))
+            return json.loads(to_text(body, errors="surrogate_or_strict"))
         return {}
 
-    def post(self, url, data, content_type='application/json', additional_headers=None):
-        return self.request(url, data=data, method='POST', content_type=content_type,
-                            additional_headers=additional_headers)
+    def post(self, url, data, content_type="application/json", additional_headers=None):
+        return self.request(
+            url, data=data, method="POST", content_type=content_type, additional_headers=additional_headers
+        )
 
     def put(self, url, data):
-        return self.request(url, data=data, method='PUT')
+        return self.request(url, data=data, method="PUT")
 
     def get(self, url):
         return self.request(url)
@@ -864,5 +868,5 @@ def main():
     jira.run()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
