@@ -1,12 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 # Copyright (c) 2018, Evert Mulder <evertmulder@gmail.com> (base on manageiq_user.py by Daniel Korn <korndaniel1@gmail.com>)
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
+from __future__ import annotations
 
-__metaclass__ = type
 
 DOCUMENTATION = r"""
 module: manageiq_group
@@ -45,19 +43,16 @@ options:
     type: int
     description:
       - The the group role ID.
-    required: false
   role:
     type: str
     description:
       - The the group role name.
       - The O(role_id) has precedence over the O(role) when supplied.
-    required: false
     default:
   tenant_id:
     type: int
     description:
       - The tenant for the group identified by the tenant ID.
-    required: false
     default:
   tenant:
     type: str
@@ -65,12 +60,10 @@ options:
       - The tenant for the group identified by the tenant name.
       - The O(tenant_id) has precedence over the O(tenant) when supplied.
       - Tenant names are case sensitive.
-    required: false
     default:
   managed_filters:
     description: The tag values per category.
     type: dict
-    required: false
     default:
   managed_filters_merge_mode:
     type: str
@@ -83,7 +76,6 @@ options:
     description: A list of strings with a reference to the allowed host, cluster or folder.
     type: list
     elements: str
-    required: false
     default:
   belongsto_filters_merge_mode:
     type: str
@@ -211,9 +203,9 @@ from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.general.plugins.module_utils.manageiq import ManageIQ, manageiq_argument_spec
 
 
-class ManageIQgroup(object):
+class ManageIQgroup:
     """
-        Object to execute group management operations in manageiq.
+    Object to execute group management operations in manageiq.
     """
 
     def __init__(self, manageiq):
@@ -224,7 +216,7 @@ class ManageIQgroup(object):
         self.client = self.manageiq.client
 
     def group(self, description):
-        """ Search for group object by description.
+        """Search for group object by description.
         Returns:
             the group, or None if group was not found.
         """
@@ -235,23 +227,23 @@ class ManageIQgroup(object):
             return groups[0]
 
     def tenant(self, tenant_id, tenant_name):
-        """ Search for tenant entity by name or id
+        """Search for tenant entity by name or id
         Returns:
             the tenant entity, None if no id or name was supplied
         """
 
         if tenant_id:
-            tenant = self.client.get_entity('tenants', tenant_id)
+            tenant = self.client.get_entity("tenants", tenant_id)
             if not tenant:
-                self.module.fail_json(msg="Tenant with id '%s' not found in manageiq" % str(tenant_id))
+                self.module.fail_json(msg=f"Tenant with id '{tenant_id}' not found in manageiq")
             return tenant
         else:
             if tenant_name:
                 tenant_res = self.client.collections.tenants.find_by(name=tenant_name)
                 if not tenant_res:
-                    self.module.fail_json(msg="Tenant '%s' not found in manageiq" % tenant_name)
+                    self.module.fail_json(msg=f"Tenant '{tenant_name}' not found in manageiq")
                 if len(tenant_res) > 1:
-                    self.module.fail_json(msg="Multiple tenants found in manageiq with name '%s'" % tenant_name)
+                    self.module.fail_json(msg=f"Multiple tenants found in manageiq with name '{tenant_name}'")
                 tenant = tenant_res[0]
                 return tenant
             else:
@@ -259,24 +251,24 @@ class ManageIQgroup(object):
                 return None
 
     def role(self, role_id, role_name):
-        """ Search for a role object by name or id.
+        """Search for a role object by name or id.
         Returns:
             the role entity, None no id or name was supplied
 
             the role, or send a module Fail signal if role not found.
         """
         if role_id:
-            role = self.client.get_entity('roles', role_id)
+            role = self.client.get_entity("roles", role_id)
             if not role:
-                self.module.fail_json(msg="Role with id '%s' not found in manageiq" % str(role_id))
+                self.module.fail_json(msg=f"Role with id '{role_id}' not found in manageiq")
             return role
         else:
             if role_name:
                 role_res = self.client.collections.roles.find_by(name=role_name)
                 if not role_res:
-                    self.module.fail_json(msg="Role '%s' not found in manageiq" % role_name)
+                    self.module.fail_json(msg=f"Role '{role_name}' not found in manageiq")
                 if len(role_res) > 1:
-                    self.module.fail_json(msg="Multiple roles found in manageiq with name '%s'" % role_name)
+                    self.module.fail_json(msg=f"Multiple roles found in manageiq with name '{role_name}'")
                 return role_res[0]
             else:
                 # No role name or role id supplied
@@ -284,7 +276,7 @@ class ManageIQgroup(object):
 
     @staticmethod
     def merge_dict_values(norm_current_values, norm_updated_values):
-        """ Create an merged update object for manageiq group filters.
+        """Create an merged update object for manageiq group filters.
 
             The input dict contain the tag values per category.
             If the new values contain the category, all tags for that category are replaced
@@ -310,7 +302,7 @@ class ManageIQgroup(object):
         return res
 
     def delete_group(self, group):
-        """ Deletes a group from manageiq.
+        """Deletes a group from manageiq.
 
         Returns:
             a dict of:
@@ -318,21 +310,28 @@ class ManageIQgroup(object):
             msg: a short message describing the operation executed.
         """
         try:
-            url = '%s/groups/%s' % (self.api_url, group['id'])
-            result = self.client.post(url, action='delete')
+            url = f"{self.api_url}/groups/{group['id']}"
+            result = self.client.post(url, action="delete")
         except Exception as e:
-            self.module.fail_json(msg="failed to delete group %s: %s" % (group['description'], str(e)))
+            self.module.fail_json(msg=f"failed to delete group {group['description']}: {e}")
 
-        if result['success'] is False:
-            self.module.fail_json(msg=result['message'])
+        if result["success"] is False:
+            self.module.fail_json(msg=result["message"])
 
-        return dict(
-            changed=True,
-            msg="deleted group %s with id %s" % (group['description'], group['id']))
+        return dict(changed=True, msg=f"deleted group {group['description']} with id {group['id']}")
 
-    def edit_group(self, group, description, role, tenant, norm_managed_filters, managed_filters_merge_mode,
-                   belongsto_filters, belongsto_filters_merge_mode):
-        """ Edit a manageiq group.
+    def edit_group(
+        self,
+        group,
+        description,
+        role,
+        tenant,
+        norm_managed_filters,
+        managed_filters_merge_mode,
+        belongsto_filters,
+        belongsto_filters_merge_mode,
+    ):
+        """Edit a manageiq group.
 
         Returns:
             a dict of:
@@ -341,66 +340,71 @@ class ManageIQgroup(object):
         """
 
         if role or norm_managed_filters or belongsto_filters:
-            group.reload(attributes=['miq_user_role_name', 'entitlement'])
+            group.reload(attributes=["miq_user_role_name", "entitlement"])
 
         try:
-            current_role = group['miq_user_role_name']
+            current_role = group["miq_user_role_name"]
         except AttributeError:
             current_role = None
 
         changed = False
         resource = {}
 
-        if description and group['description'] != description:
-            resource['description'] = description
+        if description and group["description"] != description:
+            resource["description"] = description
             changed = True
 
-        if tenant and group['tenant_id'] != tenant['id']:
-            resource['tenant'] = dict(id=tenant['id'])
+        if tenant and group["tenant_id"] != tenant["id"]:
+            resource["tenant"] = dict(id=tenant["id"])
             changed = True
 
-        if role and current_role != role['name']:
-            resource['role'] = dict(id=role['id'])
+        if role and current_role != role["name"]:
+            resource["role"] = dict(id=role["id"])
             changed = True
 
         if norm_managed_filters or belongsto_filters:
-
             # Only compare if filters are supplied
-            entitlement = group['entitlement']
+            entitlement = group["entitlement"]
 
-            if 'filters' not in entitlement:
+            if "filters" not in entitlement:
                 # No existing filters exist, use supplied filters
                 managed_tag_filters_post_body = self.normalized_managed_tag_filters_to_miq(norm_managed_filters)
-                resource['filters'] = {'managed': managed_tag_filters_post_body, "belongsto": belongsto_filters}
+                resource["filters"] = {"managed": managed_tag_filters_post_body, "belongsto": belongsto_filters}
                 changed = True
             else:
-                current_filters = entitlement['filters']
-                new_filters = self.edit_group_edit_filters(current_filters,
-                                                           norm_managed_filters, managed_filters_merge_mode,
-                                                           belongsto_filters, belongsto_filters_merge_mode)
+                current_filters = entitlement["filters"]
+                new_filters = self.edit_group_edit_filters(
+                    current_filters,
+                    norm_managed_filters,
+                    managed_filters_merge_mode,
+                    belongsto_filters,
+                    belongsto_filters_merge_mode,
+                )
                 if new_filters:
-                    resource['filters'] = new_filters
+                    resource["filters"] = new_filters
                     changed = True
 
         if not changed:
-            return dict(
-                changed=False,
-                msg="group %s is not changed." % group['description'])
+            return dict(changed=False, msg=f"group {group['description']} is not changed.")
 
         # try to update group
         try:
-            self.client.post(group['href'], action='edit', resource=resource)
+            self.client.post(group["href"], action="edit", resource=resource)
             changed = True
         except Exception as e:
-            self.module.fail_json(msg="failed to update group %s: %s" % (group['name'], str(e)))
+            self.module.fail_json(msg=f"failed to update group {group['name']}: {e!s}")
 
-        return dict(
-            changed=changed,
-            msg="successfully updated the group %s with id %s" % (group['description'], group['id']))
+        return dict(changed=changed, msg=f"successfully updated the group {group['description']} with id {group['id']}")
 
-    def edit_group_edit_filters(self, current_filters, norm_managed_filters, managed_filters_merge_mode,
-                                belongsto_filters, belongsto_filters_merge_mode):
-        """ Edit a manageiq group filters.
+    def edit_group_edit_filters(
+        self,
+        current_filters,
+        norm_managed_filters,
+        managed_filters_merge_mode,
+        belongsto_filters,
+        belongsto_filters_merge_mode,
+    ):
+        """Edit a manageiq group filters.
 
         Returns:
             None if no the group was not updated
@@ -409,7 +413,7 @@ class ManageIQgroup(object):
         filters_updated = False
         new_filters_resource = {}
 
-        current_belongsto_set = current_filters.get('belongsto', set())
+        current_belongsto_set = current_filters.get("belongsto", set())
 
         if belongsto_filters:
             new_belongsto_set = set(belongsto_filters)
@@ -417,13 +421,13 @@ class ManageIQgroup(object):
             new_belongsto_set = set()
 
         if current_belongsto_set == new_belongsto_set:
-            new_filters_resource['belongsto'] = current_filters['belongsto']
+            new_filters_resource["belongsto"] = current_filters["belongsto"]
         else:
-            if belongsto_filters_merge_mode == 'merge':
+            if belongsto_filters_merge_mode == "merge":
                 current_belongsto_set.update(new_belongsto_set)
-                new_filters_resource['belongsto'] = list(current_belongsto_set)
+                new_filters_resource["belongsto"] = list(current_belongsto_set)
             else:
-                new_filters_resource['belongsto'] = list(new_belongsto_set)
+                new_filters_resource["belongsto"] = list(new_belongsto_set)
             filters_updated = True
 
         # Process belongsto managed filter tags
@@ -434,14 +438,14 @@ class ManageIQgroup(object):
         norm_current_filters = self.manageiq_filters_to_sorted_dict(current_filters)
 
         if norm_current_filters == norm_managed_filters:
-            if 'managed' in current_filters:
-                new_filters_resource['managed'] = current_filters['managed']
+            if "managed" in current_filters:
+                new_filters_resource["managed"] = current_filters["managed"]
         else:
-            if managed_filters_merge_mode == 'merge':
+            if managed_filters_merge_mode == "merge":
                 merged_dict = self.merge_dict_values(norm_current_filters, norm_managed_filters)
-                new_filters_resource['managed'] = self.normalized_managed_tag_filters_to_miq(merged_dict)
+                new_filters_resource["managed"] = self.normalized_managed_tag_filters_to_miq(merged_dict)
             else:
-                new_filters_resource['managed'] = self.normalized_managed_tag_filters_to_miq(norm_managed_filters)
+                new_filters_resource["managed"] = self.normalized_managed_tag_filters_to_miq(norm_managed_filters)
             filters_updated = True
 
         if not filters_updated:
@@ -450,7 +454,7 @@ class ManageIQgroup(object):
         return new_filters_resource
 
     def create_group(self, description, role, tenant, norm_managed_filters, belongsto_filters):
-        """ Creates the group in manageiq.
+        """Creates the group in manageiq.
 
         Returns:
             the created group id, name, created_on timestamp,
@@ -458,33 +462,29 @@ class ManageIQgroup(object):
         """
         # check for required arguments
         for key, value in dict(description=description).items():
-            if value in (None, ''):
-                self.module.fail_json(msg="missing required argument: %s" % key)
+            if value in (None, ""):
+                self.module.fail_json(msg=f"missing required argument: {key}")
 
-        url = '%s/groups' % self.api_url
+        url = f"{self.api_url}/groups"
 
-        resource = {'description': description}
+        resource = {"description": description}
 
         if role is not None:
-            resource['role'] = dict(id=role['id'])
+            resource["role"] = dict(id=role["id"])
 
         if tenant is not None:
-            resource['tenant'] = dict(id=tenant['id'])
+            resource["tenant"] = dict(id=tenant["id"])
 
         if norm_managed_filters or belongsto_filters:
             managed_tag_filters_post_body = self.normalized_managed_tag_filters_to_miq(norm_managed_filters)
-            resource['filters'] = {'managed': managed_tag_filters_post_body, "belongsto": belongsto_filters}
+            resource["filters"] = {"managed": managed_tag_filters_post_body, "belongsto": belongsto_filters}
 
         try:
-            result = self.client.post(url, action='create', resource=resource)
+            result = self.client.post(url, action="create", resource=resource)
         except Exception as e:
-            self.module.fail_json(msg="failed to create group %s: %s" % (description, str(e)))
+            self.module.fail_json(msg=f"failed to create group {description}: {e}")
 
-        return dict(
-            changed=True,
-            msg="successfully created group %s" % description,
-            group_id=result['results'][0]['id']
-        )
+        return dict(changed=True, msg=f"successfully created group {description}", group_id=result["results"][0]["id"])
 
     @staticmethod
     def normalized_managed_tag_filters_to_miq(norm_managed_filters):
@@ -495,14 +495,14 @@ class ManageIQgroup(object):
 
     @staticmethod
     def manageiq_filters_to_sorted_dict(current_filters):
-        current_managed_filters = current_filters.get('managed')
+        current_managed_filters = current_filters.get("managed")
         if not current_managed_filters:
             return None
 
         res = {}
         for tag_list in current_managed_filters:
             tag_list.sort()
-            key = tag_list[0].split('/')[2]
+            key = tag_list[0].split("/")[2]
             res[key] = tag_list
 
         return res
@@ -516,9 +516,9 @@ class ManageIQgroup(object):
         for cat_key in managed_filters:
             cat_array = []
             if not isinstance(managed_filters[cat_key], list):
-                module.fail_json(msg='Entry "{0}" of managed_filters must be a list!'.format(cat_key))
+                module.fail_json(msg=f'Entry "{cat_key}" of managed_filters must be a list!')
             for tags in managed_filters[cat_key]:
-                miq_managed_tag = "/managed/" + cat_key + "/" + tags
+                miq_managed_tag = f"/managed/{cat_key}/{tags}"
                 cat_array.append(miq_managed_tag)
             # Do not add empty categories. ManageIQ will remove all categories that are not supplied
             if cat_array:
@@ -528,74 +528,72 @@ class ManageIQgroup(object):
 
     @staticmethod
     def create_result_group(group):
-        """ Creates the ansible result object from a manageiq group entity
+        """Creates the ansible result object from a manageiq group entity
 
         Returns:
             a dict with the group id, description, role, tenant, filters, group_type, created_on, updated_on
         """
         try:
-            role_name = group['miq_user_role_name']
+            role_name = group["miq_user_role_name"]
         except AttributeError:
             role_name = None
 
         managed_filters = None
         belongsto_filters = None
-        if 'filters' in group['entitlement']:
-            filters = group['entitlement']['filters']
-            belongsto_filters = filters.get('belongsto')
-            group_managed_filters = filters.get('managed')
+        if "filters" in group["entitlement"]:
+            filters = group["entitlement"]["filters"]
+            belongsto_filters = filters.get("belongsto")
+            group_managed_filters = filters.get("managed")
             if group_managed_filters:
                 managed_filters = {}
                 for tag_list in group_managed_filters:
-                    key = tag_list[0].split('/')[2]
+                    key = tag_list[0].split("/")[2]
                     tags = []
                     for t in tag_list:
-                        tags.append(t.split('/')[3])
+                        tags.append(t.split("/")[3])
                     managed_filters[key] = tags
 
         return dict(
-            id=group['id'],
-            description=group['description'],
+            id=group["id"],
+            description=group["description"],
             role=role_name,
-            tenant=group['tenant']['name'],
+            tenant=group["tenant"]["name"],
             managed_filters=managed_filters,
             belongsto_filters=belongsto_filters,
-            group_type=group['group_type'],
-            created_on=group['created_on'],
-            updated_on=group['updated_on'],
+            group_type=group["group_type"],
+            created_on=group["created_on"],
+            updated_on=group["updated_on"],
         )
 
 
 def main():
     argument_spec = dict(
-        description=dict(required=True, type='str'),
-        state=dict(choices=['absent', 'present'], default='present'),
-        role_id=dict(type='int'),
-        role=dict(type='str'),
-        tenant_id=dict(type='int'),
-        tenant=dict(type='str'),
-        managed_filters=dict(type='dict'),
-        managed_filters_merge_mode=dict(choices=['merge', 'replace'], default='replace'),
-        belongsto_filters=dict(type='list', elements='str'),
-        belongsto_filters_merge_mode=dict(choices=['merge', 'replace'], default='replace'),
+        description=dict(required=True, type="str"),
+        state=dict(choices=["absent", "present"], default="present"),
+        role_id=dict(type="int"),
+        role=dict(type="str"),
+        tenant_id=dict(type="int"),
+        tenant=dict(type="str"),
+        managed_filters=dict(type="dict"),
+        managed_filters_merge_mode=dict(choices=["merge", "replace"], default="replace"),
+        belongsto_filters=dict(type="list", elements="str"),
+        belongsto_filters_merge_mode=dict(choices=["merge", "replace"], default="replace"),
     )
     # add the manageiq connection arguments to the arguments
     argument_spec.update(manageiq_argument_spec())
 
-    module = AnsibleModule(
-        argument_spec=argument_spec
-    )
+    module = AnsibleModule(argument_spec=argument_spec)
 
-    description = module.params['description']
-    state = module.params['state']
-    role_id = module.params['role_id']
-    role_name = module.params['role']
-    tenant_id = module.params['tenant_id']
-    tenant_name = module.params['tenant']
-    managed_filters = module.params['managed_filters']
-    managed_filters_merge_mode = module.params['managed_filters_merge_mode']
-    belongsto_filters = module.params['belongsto_filters']
-    belongsto_filters_merge_mode = module.params['belongsto_filters_merge_mode']
+    description = module.params["description"]
+    state = module.params["state"]
+    role_id = module.params["role_id"]
+    role_name = module.params["role"]
+    tenant_id = module.params["tenant_id"]
+    tenant_name = module.params["tenant"]
+    managed_filters = module.params["managed_filters"]
+    managed_filters_merge_mode = module.params["managed_filters_merge_mode"]
+    belongsto_filters = module.params["belongsto_filters"]
+    belongsto_filters_merge_mode = module.params["belongsto_filters_merge_mode"]
 
     manageiq = ManageIQ(module)
     manageiq_group = ManageIQgroup(manageiq)
@@ -609,29 +607,33 @@ def main():
             res_args = manageiq_group.delete_group(group)
         # if we do not have a group, nothing to do
         else:
-            res_args = dict(
-                changed=False,
-                msg="group '%s' does not exist in manageiq" % description)
+            res_args = dict(changed=False, msg=f"group '{description}' does not exist in manageiq")
 
     # group should exist
     if state == "present":
-
         tenant = manageiq_group.tenant(tenant_id, tenant_name)
         role = manageiq_group.role(role_id, role_name)
         norm_managed_filters = manageiq_group.normalize_user_managed_filters_to_sorted_dict(managed_filters, module)
         # if we have a group, edit it
         if group:
-            res_args = manageiq_group.edit_group(group, description, role, tenant,
-                                                 norm_managed_filters, managed_filters_merge_mode,
-                                                 belongsto_filters, belongsto_filters_merge_mode)
+            res_args = manageiq_group.edit_group(
+                group,
+                description,
+                role,
+                tenant,
+                norm_managed_filters,
+                managed_filters_merge_mode,
+                belongsto_filters,
+                belongsto_filters_merge_mode,
+            )
 
         # if we do not have a group, create it
         else:
             res_args = manageiq_group.create_group(description, role, tenant, norm_managed_filters, belongsto_filters)
-            group = manageiq.client.get_entity('groups', res_args['group_id'])
+            group = manageiq.client.get_entity("groups", res_args["group_id"])
 
-        group.reload(expand='resources', attributes=['miq_user_role_name', 'tenant', 'entitlement'])
-        res_args['group'] = manageiq_group.create_result_group(group)
+        group.reload(expand="resources", attributes=["miq_user_role_name", "tenant", "entitlement"])
+        res_args["group"] = manageiq_group.create_result_group(group)
 
     module.exit_json(**res_args)
 
