@@ -1,12 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright (c) 2017-2018 Dell EMC Inc.
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: redfish_info
@@ -24,14 +22,12 @@ attributes:
     # This was backported to 2.5.4 and 1.3.11 as well, since this was a bugfix
 options:
   category:
-    required: false
     description:
       - List of categories to execute on OOB controller.
     default: ['Systems']
     type: list
     elements: str
   command:
-    required: false
     description:
       - List of commands to execute on OOB controller.
     type: list
@@ -66,7 +62,6 @@ options:
     type: int
     default: 60
   update_handle:
-    required: false
     description:
       - Handle to check the status of an update in progress.
     type: str
@@ -400,22 +395,52 @@ result:
 """
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.general.plugins.module_utils.redfish_utils import RedfishUtils, REDFISH_COMMON_ARGUMENT_SPEC
+from ansible_collections.community.general.plugins.module_utils.redfish_utils import (
+    RedfishUtils,
+    REDFISH_COMMON_ARGUMENT_SPEC,
+)
 
 CATEGORY_COMMANDS_ALL = {
-    "Systems": ["GetSystemInventory", "GetPsuInventory", "GetCpuInventory",
-                "GetMemoryInventory", "GetNicInventory", "GetHealthReport",
-                "GetStorageControllerInventory", "GetDiskInventory", "GetVolumeInventory",
-                "GetBiosAttributes", "GetBootOrder", "GetBootOverride", "GetVirtualMedia", "GetBiosRegistries",
-                "GetPowerRestorePolicy"],
-    "Chassis": ["GetFanInventory", "GetPsuInventory", "GetChassisPower",
-                "GetChassisThermals", "GetChassisInventory", "GetHealthReport", "GetHPEThermalConfig", "GetHPEFanPercentMin"],
+    "Systems": [
+        "GetSystemInventory",
+        "GetPsuInventory",
+        "GetCpuInventory",
+        "GetMemoryInventory",
+        "GetNicInventory",
+        "GetHealthReport",
+        "GetStorageControllerInventory",
+        "GetDiskInventory",
+        "GetVolumeInventory",
+        "GetBiosAttributes",
+        "GetBootOrder",
+        "GetBootOverride",
+        "GetVirtualMedia",
+        "GetBiosRegistries",
+        "GetPowerRestorePolicy",
+    ],
+    "Chassis": [
+        "GetFanInventory",
+        "GetPsuInventory",
+        "GetChassisPower",
+        "GetChassisThermals",
+        "GetChassisInventory",
+        "GetHealthReport",
+        "GetHPEThermalConfig",
+        "GetHPEFanPercentMin",
+    ],
     "Accounts": ["ListUsers", "GetAccountServiceConfig"],
     "Sessions": ["GetSessions"],
-    "Update": ["GetFirmwareInventory", "GetFirmwareUpdateCapabilities", "GetSoftwareInventory",
-               "GetUpdateStatus"],
-    "Manager": ["GetManagerNicInventory", "GetVirtualMedia", "GetLogs", "GetNetworkProtocols",
-                "GetHealthReport", "GetHostInterfaces", "GetManagerInventory", "GetServiceIdentification"],
+    "Update": ["GetFirmwareInventory", "GetFirmwareUpdateCapabilities", "GetSoftwareInventory", "GetUpdateStatus"],
+    "Manager": [
+        "GetManagerNicInventory",
+        "GetVirtualMedia",
+        "GetLogs",
+        "GetNetworkProtocols",
+        "GetHealthReport",
+        "GetHostInterfaces",
+        "GetManagerInventory",
+        "GetServiceIdentification",
+    ],
     "Service": ["CheckAvailability"],
 }
 
@@ -434,13 +459,13 @@ def main():
     result = {}
     category_list = []
     argument_spec = dict(
-        category=dict(type='list', elements='str', default=['Systems']),
-        command=dict(type='list', elements='str'),
+        category=dict(type="list", elements="str", default=["Systems"]),
+        command=dict(type="list", elements="str"),
         baseuri=dict(required=True),
         username=dict(),
         password=dict(no_log=True),
         auth_token=dict(no_log=True),
-        timeout=dict(type='int', default=60),
+        timeout=dict(type="int", default=60),
         update_handle=dict(),
         manager=dict(),
     )
@@ -448,64 +473,62 @@ def main():
     module = AnsibleModule(
         argument_spec,
         required_together=[
-            ('username', 'password'),
+            ("username", "password"),
         ],
         required_one_of=[
-            ('username', 'auth_token'),
+            ("username", "auth_token"),
         ],
         mutually_exclusive=[
-            ('username', 'auth_token'),
+            ("username", "auth_token"),
         ],
         supports_check_mode=True,
     )
 
     # admin credentials used for authentication
-    creds = {'user': module.params['username'],
-             'pswd': module.params['password'],
-             'token': module.params['auth_token']}
+    creds = {"user": module.params["username"], "pswd": module.params["password"], "token": module.params["auth_token"]}
 
     # timeout
-    timeout = module.params['timeout']
+    timeout = module.params["timeout"]
 
     # update handle
-    update_handle = module.params['update_handle']
+    update_handle = module.params["update_handle"]
 
     # manager
-    manager = module.params['manager']
+    manager = module.params["manager"]
 
     # Build root URI
-    root_uri = "https://" + module.params['baseuri']
+    root_uri = f"https://{module.params['baseuri']}"
     rf_utils = RedfishUtils(creds, root_uri, timeout, module)
 
     # Build Category list
-    if "all" in module.params['category']:
+    if "all" in module.params["category"]:
         for entry in CATEGORY_COMMANDS_ALL:
             category_list.append(entry)
     else:
         # one or more categories specified
-        category_list = module.params['category']
+        category_list = module.params["category"]
 
     for category in category_list:
         command_list = []
         # Build Command list for each Category
         if category in CATEGORY_COMMANDS_ALL:
-            if not module.params['command']:
+            if not module.params["command"]:
                 # True if we don't specify a command --> use default
                 command_list.append(CATEGORY_COMMANDS_DEFAULT[category])
-            elif "all" in module.params['command']:
+            elif "all" in module.params["command"]:
                 for entry in range(len(CATEGORY_COMMANDS_ALL[category])):
                     command_list.append(CATEGORY_COMMANDS_ALL[category][entry])
             # one or more commands
             else:
-                command_list = module.params['command']
+                command_list = module.params["command"]
                 # Verify that all commands are valid
                 for cmd in command_list:
                     # Fail if even one command given is invalid
                     if cmd not in CATEGORY_COMMANDS_ALL[category]:
-                        module.fail_json(msg="Invalid Command: %s" % cmd)
+                        module.fail_json(msg=f"Invalid Command: {cmd}")
         else:
             # Fail if even one category given is invalid
-            module.fail_json(msg="Invalid Category: %s" % category)
+            module.fail_json(msg=f"Invalid Category: {category}")
 
         # Organize by Categories / Commands
         if category == "Service":
@@ -517,8 +540,8 @@ def main():
         elif category == "Systems":
             # execute only if we find a Systems resource
             resource = rf_utils._find_systems_resource()
-            if resource['ret'] is False:
-                module.fail_json(msg=resource['msg'])
+            if resource["ret"] is False:
+                module.fail_json(msg=resource["msg"])
 
             for command in command_list:
                 if command == "GetSystemInventory":
@@ -553,8 +576,8 @@ def main():
         elif category == "Chassis":
             # execute only if we find Chassis resource
             resource = rf_utils._find_chassis_resource()
-            if resource['ret'] is False:
-                module.fail_json(msg=resource['msg'])
+            if resource["ret"] is False:
+                module.fail_json(msg=resource["msg"])
 
             for command in command_list:
                 if command == "GetFanInventory":
@@ -577,8 +600,8 @@ def main():
         elif category == "Accounts":
             # execute only if we find an Account service resource
             resource = rf_utils._find_accountservice_resource()
-            if resource['ret'] is False:
-                module.fail_json(msg=resource['msg'])
+            if resource["ret"] is False:
+                module.fail_json(msg=resource["msg"])
 
             for command in command_list:
                 if command == "ListUsers":
@@ -589,8 +612,8 @@ def main():
         elif category == "Update":
             # execute only if we find UpdateService resources
             resource = rf_utils._find_updateservice_resource()
-            if resource['ret'] is False:
-                module.fail_json(msg=resource['msg'])
+            if resource["ret"] is False:
+                module.fail_json(msg=resource["msg"])
 
             for command in command_list:
                 if command == "GetFirmwareInventory":
@@ -605,8 +628,8 @@ def main():
         elif category == "Sessions":
             # execute only if we find SessionService resources
             resource = rf_utils._find_sessionservice_resource()
-            if resource['ret'] is False:
-                module.fail_json(msg=resource['msg'])
+            if resource["ret"] is False:
+                module.fail_json(msg=resource["msg"])
 
             for command in command_list:
                 if command == "GetSessions":
@@ -615,8 +638,8 @@ def main():
         elif category == "Manager":
             # execute only if we find a Manager service resource
             resource = rf_utils._find_managers_resource()
-            if resource['ret'] is False:
-                module.fail_json(msg=resource['msg'])
+            if resource["ret"] is False:
+                module.fail_json(msg=resource["msg"])
 
             for command in command_list:
                 if command == "GetManagerNicInventory":
@@ -640,5 +663,5 @@ def main():
     module.exit_json(redfish_facts=result)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
