@@ -1,12 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright (c) 2018, Red Hat, Inc.
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 author:
@@ -229,6 +227,7 @@ import traceback
 YAML_IMP_ERR = None
 try:
     import yaml
+
     HAS_YAML = True
 except ImportError:
     YAML_IMP_ERR = traceback.format_exc()
@@ -256,13 +255,13 @@ def inventory_vdos(module, vdocmd):
         return vdolist
 
     if rc != 0:
-        module.fail_json(msg="Inventorying VDOs failed: %s" % vdostatusout, rc=rc, err=err)
+        module.fail_json(msg=f"Inventorying VDOs failed: {vdostatusout}", rc=rc, err=err)
 
     vdostatusyaml = yaml.safe_load(vdostatusout)
     if vdostatusyaml is None:
         return vdolist
 
-    vdoyamls = vdostatusyaml['VDOs']
+    vdoyamls = vdostatusyaml["VDOs"]
 
     if vdoyamls is not None:
         vdolist = list(vdoyamls.keys())
@@ -272,7 +271,7 @@ def inventory_vdos(module, vdocmd):
 
 def list_running_vdos(module, vdocmd):
     rc, vdolistout, err = module.run_command([vdocmd, "list"])
-    runningvdolist = filter(None, vdolistout.split('\n'))
+    runningvdolist = [_f for _f in vdolistout.split("\n") if _f]
     return runningvdolist
 
 
@@ -285,61 +284,61 @@ def list_running_vdos(module, vdocmd):
 #
 # @return vdocmdoptions  A string to be used in a 'vdo <action>' command.
 def start_vdo(module, vdoname, vdocmd):
-    rc, out, err = module.run_command([vdocmd, "start", "--name=%s" % vdoname])
+    rc, out, err = module.run_command([vdocmd, "start", f"--name={vdoname}"])
     if rc == 0:
-        module.log("started VDO volume %s" % vdoname)
+        module.log(f"started VDO volume {vdoname}")
     return rc
 
 
 def stop_vdo(module, vdoname, vdocmd):
-    rc, out, err = module.run_command([vdocmd, "stop", "--name=%s" % vdoname])
+    rc, out, err = module.run_command([vdocmd, "stop", f"--name={vdoname}"])
     if rc == 0:
-        module.log("stopped VDO volume %s" % vdoname)
+        module.log(f"stopped VDO volume {vdoname}")
     return rc
 
 
 def activate_vdo(module, vdoname, vdocmd):
-    rc, out, err = module.run_command([vdocmd, "activate", "--name=%s" % vdoname])
+    rc, out, err = module.run_command([vdocmd, "activate", f"--name={vdoname}"])
     if rc == 0:
-        module.log("activated VDO volume %s" % vdoname)
+        module.log(f"activated VDO volume {vdoname}")
     return rc
 
 
 def deactivate_vdo(module, vdoname, vdocmd):
-    rc, out, err = module.run_command([vdocmd, "deactivate", "--name=%s" % vdoname])
+    rc, out, err = module.run_command([vdocmd, "deactivate", f"--name={vdoname}"])
     if rc == 0:
-        module.log("deactivated VDO volume %s" % vdoname)
+        module.log(f"deactivated VDO volume {vdoname}")
     return rc
 
 
 def add_vdooptions(params):
     options = []
 
-    if params.get('logicalsize') is not None:
-        options.append("--vdoLogicalSize=" + params['logicalsize'])
+    if params.get("logicalsize") is not None:
+        options.append(f"--vdoLogicalSize={params['logicalsize']}")
 
-    if params.get('blockmapcachesize') is not None:
-        options.append("--blockMapCacheSize=" + params['blockmapcachesize'])
+    if params.get("blockmapcachesize") is not None:
+        options.append(f"--blockMapCacheSize={params['blockmapcachesize']}")
 
-    if params.get('readcache') == 'enabled':
+    if params.get("readcache") == "enabled":
         options.append("--readCache=enabled")
 
-    if params.get('readcachesize') is not None:
-        options.append("--readCacheSize=" + params['readcachesize'])
+    if params.get("readcachesize") is not None:
+        options.append(f"--readCacheSize={params['readcachesize']}")
 
-    if params.get('slabsize') is not None:
-        options.append("--vdoSlabSize=" + params['slabsize'])
+    if params.get("slabsize") is not None:
+        options.append(f"--vdoSlabSize={params['slabsize']}")
 
-    if params.get('emulate512'):
+    if params.get("emulate512"):
         options.append("--emulate512=enabled")
 
-    if params.get('indexmem') is not None:
-        options.append("--indexMem=" + params['indexmem'])
+    if params.get("indexmem") is not None:
+        options.append(f"--indexMem={params['indexmem']}")
 
-    if params.get('indexmode') == 'sparse':
+    if params.get("indexmode") == "sparse":
         options.append("--sparseIndex=enabled")
 
-    if params.get('force'):
+    if params.get("force"):
         options.append("--force")
 
     # Entering an invalid thread config results in a cryptic
@@ -348,26 +347,25 @@ def add_vdooptions(params):
     # output a more helpful message, but one would have to log
     # onto that system to read the error.  For now, heed the thread
     # limit warnings in the DOCUMENTATION section above.
-    if params.get('ackthreads') is not None:
-        options.append("--vdoAckThreads=" + params['ackthreads'])
+    if params.get("ackthreads") is not None:
+        options.append(f"--vdoAckThreads={params['ackthreads']}")
 
-    if params.get('biothreads') is not None:
-        options.append("--vdoBioThreads=" + params['biothreads'])
+    if params.get("biothreads") is not None:
+        options.append(f"--vdoBioThreads={params['biothreads']}")
 
-    if params.get('cputhreads') is not None:
-        options.append("--vdoCpuThreads=" + params['cputhreads'])
+    if params.get("cputhreads") is not None:
+        options.append(f"--vdoCpuThreads={params['cputhreads']}")
 
-    if params.get('logicalthreads') is not None:
-        options.append("--vdoLogicalThreads=" + params['logicalthreads'])
+    if params.get("logicalthreads") is not None:
+        options.append(f"--vdoLogicalThreads={params['logicalthreads']}")
 
-    if params.get('physicalthreads') is not None:
-        options.append("--vdoPhysicalThreads=" + params['physicalthreads'])
+    if params.get("physicalthreads") is not None:
+        options.append(f"--vdoPhysicalThreads={params['physicalthreads']}")
 
     return options
 
 
 def run_module():
-
     # Define the available arguments/parameters that a user can pass to
     # the module.
     # Defaults for VDO parameters are None, in order to facilitate
@@ -375,29 +373,29 @@ def run_module():
     # Creation param defaults are determined by the creation section.
 
     module_args = dict(
-        name=dict(type='str', required=True),
-        state=dict(type='str', default='present', choices=['absent', 'present']),
-        activated=dict(type='bool'),
-        running=dict(type='bool'),
-        growphysical=dict(type='bool', default=False),
-        device=dict(type='str'),
-        logicalsize=dict(type='str'),
-        deduplication=dict(type='str', choices=['disabled', 'enabled']),
-        compression=dict(type='str', choices=['disabled', 'enabled']),
-        blockmapcachesize=dict(type='str'),
-        readcache=dict(type='str', choices=['disabled', 'enabled']),
-        readcachesize=dict(type='str'),
-        emulate512=dict(type='bool', default=False),
-        slabsize=dict(type='str'),
-        writepolicy=dict(type='str', choices=['async', 'auto', 'sync']),
-        indexmem=dict(type='str'),
-        indexmode=dict(type='str', choices=['dense', 'sparse']),
-        ackthreads=dict(type='str'),
-        biothreads=dict(type='str'),
-        cputhreads=dict(type='str'),
-        logicalthreads=dict(type='str'),
-        physicalthreads=dict(type='str'),
-        force=dict(type='bool', default=False),
+        name=dict(type="str", required=True),
+        state=dict(type="str", default="present", choices=["absent", "present"]),
+        activated=dict(type="bool"),
+        running=dict(type="bool"),
+        growphysical=dict(type="bool", default=False),
+        device=dict(type="str"),
+        logicalsize=dict(type="str"),
+        deduplication=dict(type="str", choices=["disabled", "enabled"]),
+        compression=dict(type="str", choices=["disabled", "enabled"]),
+        blockmapcachesize=dict(type="str"),
+        readcache=dict(type="str", choices=["disabled", "enabled"]),
+        readcachesize=dict(type="str"),
+        emulate512=dict(type="bool", default=False),
+        slabsize=dict(type="str"),
+        writepolicy=dict(type="str", choices=["async", "auto", "sync"]),
+        indexmem=dict(type="str"),
+        indexmode=dict(type="str", choices=["dense", "sparse"]),
+        ackthreads=dict(type="str"),
+        biothreads=dict(type="str"),
+        cputhreads=dict(type="str"),
+        logicalthreads=dict(type="str"),
+        physicalthreads=dict(type="str"),
+        force=dict(type="bool", default=False),
     )
 
     # Seed the result dictionary in the object.  There will be an
@@ -417,11 +415,11 @@ def run_module():
     )
 
     if not HAS_YAML:
-        module.fail_json(msg=missing_required_lib('PyYAML'), exception=YAML_IMP_ERR)
+        module.fail_json(msg=missing_required_lib("PyYAML"), exception=YAML_IMP_ERR)
 
     vdocmd = module.get_bin_path("vdo", required=True)
     if not vdocmd:
-        module.fail_json(msg='VDO is not installed.', **result)
+        module.fail_json(msg="VDO is not installed.", **result)
 
     # Print a pre-run list of VDO volumes in the result object.
     vdolist = inventory_vdos(module, vdocmd)
@@ -430,15 +428,14 @@ def run_module():
 
     # Collect the name of the desired VDO volume, and its state.  These will
     # determine what to do.
-    desiredvdo = module.params['name']
-    state = module.params['state']
+    desiredvdo = module.params["name"]
+    state = module.params["state"]
 
     # Create a desired VDO volume that doesn't exist yet.
-    if (desiredvdo not in vdolist) and (state == 'present'):
-        device = module.params['device']
+    if (desiredvdo not in vdolist) and (state == "present"):
+        device = module.params["device"]
         if device is None:
-            module.fail_json(msg="Creating a VDO volume requires specifying "
-                                 "a 'device' in the playbook.")
+            module.fail_json(msg="Creating a VDO volume requires specifying a 'device' in the playbook.")
 
         # Create a dictionary of the options from the AnsibleModule
         # parameters, compile the vdo command options, and run "vdo create"
@@ -448,71 +445,74 @@ def run_module():
         # assume default values.
         vdocmdoptions = add_vdooptions(module.params)
         rc, out, err = module.run_command(
-            [vdocmd, "create", "--name=%s" % desiredvdo, "--device=%s" % device] + vdocmdoptions)
+            [vdocmd, "create", f"--name={desiredvdo}", f"--device={device}"] + vdocmdoptions
+        )
         if rc == 0:
-            result['changed'] = True
+            result["changed"] = True
         else:
-            module.fail_json(msg="Creating VDO %s failed." % desiredvdo, rc=rc, err=err)
+            module.fail_json(msg=f"Creating VDO {desiredvdo} failed.", rc=rc, err=err)
 
-        if module.params['compression'] == 'disabled':
-            rc, out, err = module.run_command([vdocmd, "disableCompression", "--name=%s" % desiredvdo])
+        if module.params["compression"] == "disabled":
+            rc, out, err = module.run_command([vdocmd, "disableCompression", f"--name={desiredvdo}"])
 
-        if module.params['deduplication'] == 'disabled':
-            rc, out, err = module.run_command([vdocmd, "disableDeduplication", "--name=%s" % desiredvdo])
+        if module.params["deduplication"] == "disabled":
+            rc, out, err = module.run_command([vdocmd, "disableDeduplication", f"--name={desiredvdo}"])
 
-        if module.params['activated'] is False:
+        if module.params["activated"] is False:
             deactivate_vdo(module, desiredvdo, vdocmd)
 
-        if module.params['running'] is False:
+        if module.params["running"] is False:
             stop_vdo(module, desiredvdo, vdocmd)
 
         # Print a post-run list of VDO volumes in the result object.
         vdolist = inventory_vdos(module, vdocmd)
-        module.log("created VDO volume %s" % desiredvdo)
+        module.log(f"created VDO volume {desiredvdo}")
         module.exit_json(**result)
 
     # Modify the current parameters of a VDO that exists.
-    if desiredvdo in vdolist and state == 'present':
+    if desiredvdo in vdolist and state == "present":
         rc, vdostatusoutput, err = module.run_command([vdocmd, "status"])
         vdostatusyaml = yaml.safe_load(vdostatusoutput)
 
         # An empty dictionary to contain dictionaries of VDO statistics
         processedvdos = {}
 
-        vdoyamls = vdostatusyaml['VDOs']
+        vdoyamls = vdostatusyaml["VDOs"]
         if vdoyamls is not None:
             processedvdos = vdoyamls
 
         # The 'vdo status' keys that are currently modifiable.
-        statusparamkeys = ['Acknowledgement threads',
-                           'Bio submission threads',
-                           'Block map cache size',
-                           'CPU-work threads',
-                           'Logical threads',
-                           'Physical threads',
-                           'Read cache',
-                           'Read cache size',
-                           'Configured write policy',
-                           'Compression',
-                           'Deduplication']
+        statusparamkeys = [
+            "Acknowledgement threads",
+            "Bio submission threads",
+            "Block map cache size",
+            "CPU-work threads",
+            "Logical threads",
+            "Physical threads",
+            "Read cache",
+            "Read cache size",
+            "Configured write policy",
+            "Compression",
+            "Deduplication",
+        ]
 
         # A key translation table from 'vdo status' output to Ansible
         # module parameters.  This covers all of the 'vdo status'
         # parameter keys that could be modified with the 'vdo'
         # command.
         vdokeytrans = {
-            'Logical size': 'logicalsize',
-            'Compression': 'compression',
-            'Deduplication': 'deduplication',
-            'Block map cache size': 'blockmapcachesize',
-            'Read cache': 'readcache',
-            'Read cache size': 'readcachesize',
-            'Configured write policy': 'writepolicy',
-            'Acknowledgement threads': 'ackthreads',
-            'Bio submission threads': 'biothreads',
-            'CPU-work threads': 'cputhreads',
-            'Logical threads': 'logicalthreads',
-            'Physical threads': 'physicalthreads'
+            "Logical size": "logicalsize",
+            "Compression": "compression",
+            "Deduplication": "deduplication",
+            "Block map cache size": "blockmapcachesize",
+            "Read cache": "readcache",
+            "Read cache size": "readcachesize",
+            "Configured write policy": "writepolicy",
+            "Acknowledgement threads": "ackthreads",
+            "Bio submission threads": "biothreads",
+            "CPU-work threads": "cputhreads",
+            "Logical threads": "logicalthreads",
+            "Physical threads": "physicalthreads",
         }
 
         # Build a dictionary of the current VDO status parameters, with
@@ -549,49 +549,52 @@ def run_module():
         if diffparams:
             vdocmdoptions = add_vdooptions(diffparams)
             if vdocmdoptions:
-                rc, out, err = module.run_command([vdocmd, "modify", "--name=%s" % desiredvdo] + vdocmdoptions)
+                rc, out, err = module.run_command([vdocmd, "modify", f"--name={desiredvdo}"] + vdocmdoptions)
                 if rc == 0:
-                    result['changed'] = True
+                    result["changed"] = True
                 else:
-                    module.fail_json(msg="Modifying VDO %s failed."
-                                     % desiredvdo, rc=rc, err=err)
+                    module.fail_json(msg=f"Modifying VDO {desiredvdo} failed.", rc=rc, err=err)
 
-            if 'deduplication' in diffparams.keys():
-                dedupemod = diffparams['deduplication']
-                dedupeparam = "disableDeduplication" if dedupemod == 'disabled' else "enableDeduplication"
-                rc, out, err = module.run_command([vdocmd, dedupeparam, "--name=%s" % desiredvdo])
+            if "deduplication" in diffparams.keys():
+                dedupemod = diffparams["deduplication"]
+                dedupeparam = "disableDeduplication" if dedupemod == "disabled" else "enableDeduplication"
+                rc, out, err = module.run_command([vdocmd, dedupeparam, f"--name={desiredvdo}"])
 
                 if rc == 0:
-                    result['changed'] = True
+                    result["changed"] = True
                 else:
-                    module.fail_json(msg="Changing deduplication on VDO volume %s failed." % desiredvdo, rc=rc, err=err)
+                    module.fail_json(msg=f"Changing deduplication on VDO volume {desiredvdo} failed.", rc=rc, err=err)
 
-            if 'compression' in diffparams.keys():
-                compressmod = diffparams['compression']
-                compressparam = "disableCompression" if compressmod == 'disabled' else "enableCompression"
-                rc, out, err = module.run_command([vdocmd, compressparam, "--name=%s" % desiredvdo])
+            if "compression" in diffparams.keys():
+                compressmod = diffparams["compression"]
+                compressparam = "disableCompression" if compressmod == "disabled" else "enableCompression"
+                rc, out, err = module.run_command([vdocmd, compressparam, f"--name={desiredvdo}"])
                 if rc == 0:
-                    result['changed'] = True
+                    result["changed"] = True
                 else:
-                    module.fail_json(msg="Changing compression on VDO volume %s failed." % desiredvdo, rc=rc, err=err)
+                    module.fail_json(msg=f"Changing compression on VDO volume {desiredvdo} failed.", rc=rc, err=err)
 
-            if 'writepolicy' in diffparams.keys():
-                writepolmod = diffparams['writepolicy']
-                rc, out, err = module.run_command([
-                    vdocmd,
-                    "changeWritePolicy",
-                    "--name=%s" % desiredvdo,
-                    "--writePolicy=%s" % writepolmod,
-                ])
+            if "writepolicy" in diffparams.keys():
+                writepolmod = diffparams["writepolicy"]
+                rc, out, err = module.run_command(
+                    [
+                        vdocmd,
+                        "changeWritePolicy",
+                        f"--name={desiredvdo}",
+                        f"--writePolicy={writepolmod}",
+                    ]
+                )
 
                 if rc == 0:
-                    result['changed'] = True
+                    result["changed"] = True
                 else:
-                    module.fail_json(msg="Changing write policy on VDO volume %s failed." % desiredvdo, rc=rc, err=err)
+                    module.fail_json(msg=f"Changing write policy on VDO volume {desiredvdo} failed.", rc=rc, err=err)
 
         # Process the size parameters, to determine of a growPhysical or
         # growLogical operation needs to occur.
-        sizeparamkeys = ['Logical size', ]
+        sizeparamkeys = [
+            "Logical size",
+        ]
 
         currentsizeparams = {}
         sizetrans = {}
@@ -608,13 +611,13 @@ def run_module():
             if module.params[key] is not None and str(sizeparams[key]) != module.params[key]:
                 diffsizeparams[key] = module.params[key]
 
-        if module.params['growphysical']:
-            physdevice = module.params['device']
+        if module.params["growphysical"]:
+            physdevice = module.params["device"]
             rc, devsectors, err = module.run_command([module.get_bin_path("blockdev"), "--getsz", physdevice])
-            devblocks = (int(devsectors) / 8)
-            dmvdoname = ('/dev/mapper/' + desiredvdo)
-            currentvdostats = processedvdos[desiredvdo]['VDO statistics'][dmvdoname]
-            currentphysblocks = currentvdostats['physical blocks']
+            devblocks = int(devsectors) / 8
+            dmvdoname = f"/dev/mapper/{desiredvdo}"
+            currentvdostats = processedvdos[desiredvdo]["VDO statistics"][dmvdoname]
+            currentphysblocks = currentvdostats["physical blocks"]
 
             # Set a growPhysical threshold to grow only when there is
             # guaranteed to be more than 2 slabs worth of unallocated
@@ -624,29 +627,31 @@ def run_module():
             growthresh = devblocks + 16777216
 
             if currentphysblocks > growthresh:
-                result['changed'] = True
-                rc, out, err = module.run_command([vdocmd, "growPhysical", "--name=%s" % desiredvdo])
+                result["changed"] = True
+                rc, out, err = module.run_command([vdocmd, "growPhysical", f"--name={desiredvdo}"])
 
-        if 'logicalsize' in diffsizeparams.keys():
-            result['changed'] = True
-            rc, out, err = module.run_command([vdocmd, "growLogical", "--name=%s" % desiredvdo, "--vdoLogicalSize=%s" % diffsizeparams['logicalsize']])
+        if "logicalsize" in diffsizeparams.keys():
+            result["changed"] = True
+            rc, out, err = module.run_command(
+                [vdocmd, "growLogical", f"--name={desiredvdo}", f"--vdoLogicalSize={diffsizeparams['logicalsize']}"]
+            )
 
-        vdoactivatestatus = processedvdos[desiredvdo]['Activate']
+        vdoactivatestatus = processedvdos[desiredvdo]["Activate"]
 
-        if module.params['activated'] is False and vdoactivatestatus == 'enabled':
+        if module.params["activated"] is False and vdoactivatestatus == "enabled":
             deactivate_vdo(module, desiredvdo, vdocmd)
-            if not result['changed']:
-                result['changed'] = True
+            if not result["changed"]:
+                result["changed"] = True
 
-        if module.params['activated'] and vdoactivatestatus == 'disabled':
+        if module.params["activated"] and vdoactivatestatus == "disabled":
             activate_vdo(module, desiredvdo, vdocmd)
-            if not result['changed']:
-                result['changed'] = True
+            if not result["changed"]:
+                result["changed"] = True
 
-        if module.params['running'] is False and desiredvdo in runningvdolist:
+        if module.params["running"] is False and desiredvdo in runningvdolist:
             stop_vdo(module, desiredvdo, vdocmd)
-            if not result['changed']:
-                result['changed'] = True
+            if not result["changed"]:
+                result["changed"] = True
 
         # Note that a disabled VDO volume cannot be started by the
         # 'vdo start' command, by design.  To accurately track changed
@@ -655,29 +660,33 @@ def run_module():
         # the activate_vdo() operation succeeded, as 'vdoactivatestatus'
         # will have the activated status prior to the activate_vdo()
         # call.
-        if (vdoactivatestatus == 'enabled' or module.params['activated']) and module.params['running'] and desiredvdo not in runningvdolist:
+        if (
+            (vdoactivatestatus == "enabled" or module.params["activated"])
+            and module.params["running"]
+            and desiredvdo not in runningvdolist
+        ):
             start_vdo(module, desiredvdo, vdocmd)
-            if not result['changed']:
-                result['changed'] = True
+            if not result["changed"]:
+                result["changed"] = True
 
         # Print a post-run list of VDO volumes in the result object.
         vdolist = inventory_vdos(module, vdocmd)
         if diffparams:
-            module.log("modified parameters of VDO volume %s" % desiredvdo)
+            module.log(f"modified parameters of VDO volume {desiredvdo}")
 
         module.exit_json(**result)
 
     # Remove a desired VDO that currently exists.
-    if desiredvdo in vdolist and state == 'absent':
-        rc, out, err = module.run_command([vdocmd, "remove", "--name=%s" % desiredvdo])
+    if desiredvdo in vdolist and state == "absent":
+        rc, out, err = module.run_command([vdocmd, "remove", f"--name={desiredvdo}"])
         if rc == 0:
-            result['changed'] = True
+            result["changed"] = True
         else:
-            module.fail_json(msg="Removing VDO %s failed." % desiredvdo, rc=rc, err=err)
+            module.fail_json(msg=f"Removing VDO {desiredvdo} failed.", rc=rc, err=err)
 
         # Print a post-run list of VDO volumes in the result object.
         vdolist = inventory_vdos(module, vdocmd)
-        module.log("removed VDO volume %s" % desiredvdo)
+        module.log(f"removed VDO volume {desiredvdo}")
         module.exit_json(**result)
 
     # fall through
@@ -685,7 +694,7 @@ def run_module():
     # not exist. Print a post-run list of VDO volumes in the result
     # object.
     vdolist = inventory_vdos(module, vdocmd)
-    module.log("received request to remove non-existent VDO volume %s" % desiredvdo)
+    module.log(f"received request to remove non-existent VDO volume {desiredvdo}")
 
     module.exit_json(**result)
 
@@ -694,5 +703,5 @@ def main():
     run_module()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
