@@ -12,6 +12,10 @@ DOCUMENTATION = r'''
 ---
 module: postgresql_set
 short_description: Change a PostgreSQL server configuration parameter
+deprecated:
+  removed_in: "5.0.0"
+  why: It has been replaced with a better-designed module.
+  alternative: Use M(community.postgresql.postgresql_alter_system) instead.
 description:
    - "IMPORTANT: If your PostgreSQL server version is 14 or later,
      use the M(community.postgresql.postgresql_alter_system) module instead as it will
@@ -188,7 +192,7 @@ queries:
 
 from copy import deepcopy
 
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.postgresql.plugins.module_utils.database import \
     check_input
