@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -269,6 +272,13 @@ options:
                                 choices:
                                     - 'disable'
                                     - 'enable'
+                            verify_cert:
+                                aliases: ['verify-cert']
+                                type: str
+                                description: Enable/disable certificate verification of the real server.
+                                choices:
+                                    - 'disable'
+                                    - 'enable'
                     saml_redirect:
                         aliases: ['saml-redirect']
                         type: str
@@ -676,6 +686,13 @@ options:
                                 choices:
                                     - 'disable'
                                     - 'enable'
+                            verify_cert:
+                                aliases: ['verify-cert']
+                                type: str
+                                description: Enable/disable certificate verification of the real server.
+                                choices:
+                                    - 'disable'
+                                    - 'enable'
                     saml_redirect:
                         aliases: ['saml-redirect']
                         type: str
@@ -993,6 +1010,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -1001,8 +1019,8 @@ EXAMPLES = '''
     - name: Configure IPv6 access proxy.
       fortinet.fortimanager.fmgr_firewall_accessproxy6:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -1043,6 +1061,7 @@ EXAMPLES = '''
           #         translate_host: <value in [disable, enable]>
           #         external_auth: <value in [disable, enable]>
           #         tunnel_encryption: <value in [disable, enable]>
+          #         verify_cert: <value in [disable, enable]>
           #     saml_redirect: <value in [disable, enable]>
           #     saml_server: <string>
           #     service: <value in [http, https, tcp-forwarding, ...]>
@@ -1107,6 +1126,7 @@ EXAMPLES = '''
           #         translate_host: <value in [disable, enable]>
           #         external_auth: <value in [disable, enable]>
           #         tunnel_encryption: <value in [disable, enable]>
+          #         verify_cert: <value in [disable, enable]>
           #     saml_redirect: <value in [disable, enable]>
           #     saml_server: <string>
           #     service: <value in [http, https, tcp-forwarding, ...]>
@@ -1207,6 +1227,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_accessproxy6': {
             'type': 'dict',
             'v_range': [['7.2.1', '']],
@@ -1254,7 +1275,8 @@ def main():
                                 'weight': {'v_range': [['7.2.1', '']], 'type': 'int'},
                                 'translate-host': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                                 'external-auth': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                                'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                                'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                                'verify-cert': {'v_range': [['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
                             },
                             'elements': 'dict'
                         },
@@ -1384,7 +1406,8 @@ def main():
                                 'weight': {'v_range': [['7.2.1', '']], 'type': 'int'},
                                 'translate-host': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                                 'external-auth': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                                'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                                'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                                'verify-cert': {'v_range': [['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
                             },
                             'elements': 'dict'
                         },
