@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -86,15 +89,18 @@ options:
         required: false
         type: dict
         suboptions:
-            comfort-amount:
+            comfort_amount:
+                aliases: ['comfort-amount']
                 type: int
-                description: Deprecated, please rename it to comfort_amount. Amount of data to send in a transmission for client comforting
-            comfort-interval:
+                description: Amount of data to send in a transmission for client comforting
+            comfort_interval:
+                aliases: ['comfort-interval']
                 type: int
-                description: Deprecated, please rename it to comfort_interval. Period of time between start, or last transmission, and the next client ...
-            inspect-all:
+                description: Period of time between start, or last transmission, and the next client comfort transmission of data
+            inspect_all:
+                aliases: ['inspect-all']
                 type: str
-                description: Deprecated, please rename it to inspect_all. Enable/disable the inspection of all ports for the protocol.
+                description: Enable/disable the inspection of all ports for the protocol.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -109,15 +115,17 @@ options:
                     - 'splice'
                     - 'bypass-rest-command'
                     - 'bypass-mode-command'
-            oversize-limit:
+            oversize_limit:
+                aliases: ['oversize-limit']
                 type: int
-                description: Deprecated, please rename it to oversize_limit. Maximum in-memory file size that can be scanned
+                description: Maximum in-memory file size that can be scanned
             ports:
                 type: raw
                 description: (list) Ports to scan for content
-            scan-bzip2:
+            scan_bzip2:
+                aliases: ['scan-bzip2']
                 type: str
-                description: Deprecated, please rename it to scan_bzip2. Enable/disable scanning of BZip2 compressed files.
+                description: Enable/disable scanning of BZip2 compressed files.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -127,41 +135,50 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            uncompressed-nest-limit:
+            uncompressed_nest_limit:
+                aliases: ['uncompressed-nest-limit']
                 type: int
-                description: Deprecated, please rename it to uncompressed_nest_limit. Maximum nested levels of compression that can be uncompressed and...
-            uncompressed-oversize-limit:
+                description: Maximum nested levels of compression that can be uncompressed and scanned
+            uncompressed_oversize_limit:
+                aliases: ['uncompressed-oversize-limit']
                 type: int
-                description: Deprecated, please rename it to uncompressed_oversize_limit. Maximum in-memory uncompressed file size that can be scanned
-            ssl-offloaded:
+                description: Maximum in-memory uncompressed file size that can be scanned
+            ssl_offloaded:
+                aliases: ['ssl-offloaded']
                 type: str
-                description: Deprecated, please rename it to ssl_offloaded. SSL decryption and encryption performed by an external device.
+                description: SSL decryption and encryption performed by an external device.
                 choices:
                     - 'no'
                     - 'yes'
-            stream-based-uncompressed-limit:
+            stream_based_uncompressed_limit:
+                aliases: ['stream-based-uncompressed-limit']
                 type: int
-                description: Deprecated, please rename it to stream_based_uncompressed_limit. Maximum stream-based uncompressed data size that will be ...
-            tcp-window-maximum:
+                description: Maximum stream-based uncompressed data size that will be scanned
+            tcp_window_maximum:
+                aliases: ['tcp-window-maximum']
                 type: int
-                description: Deprecated, please rename it to tcp_window_maximum. Maximum dynamic TCP window size.
-            tcp-window-minimum:
+                description: Maximum dynamic TCP window size.
+            tcp_window_minimum:
+                aliases: ['tcp-window-minimum']
                 type: int
-                description: Deprecated, please rename it to tcp_window_minimum. Minimum dynamic TCP window size.
-            tcp-window-size:
+                description: Minimum dynamic TCP window size.
+            tcp_window_size:
+                aliases: ['tcp-window-size']
                 type: int
-                description: Deprecated, please rename it to tcp_window_size. Set TCP static window size.
-            tcp-window-type:
+                description: Set TCP static window size.
+            tcp_window_type:
+                aliases: ['tcp-window-type']
                 type: str
-                description: Deprecated, please rename it to tcp_window_type. TCP window type to use for this protocol.
+                description: TCP window type to use for this protocol.
                 choices:
                     - 'system'
                     - 'static'
                     - 'dynamic'
                     - 'auto-tuning'
-            explicit-ftp-tls:
+            explicit_ftp_tls:
+                aliases: ['explicit-ftp-tls']
                 type: str
-                description: Deprecated, please rename it to explicit_ftp_tls. Enable/disable FTP redirection for explicit FTPS.
+                description: Enable/disable FTP redirection for explicit FTPS.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -171,6 +188,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -179,36 +197,36 @@ EXAMPLES = '''
     - name: Configure FTP protocol options.
       fortinet.fortimanager.fmgr_firewall_profileprotocoloptions_ftp:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile_protocol_options: <your own value>
         firewall_profileprotocoloptions_ftp:
-          comfort_amount: <integer>
-          comfort_interval: <integer>
-          inspect_all: <value in [disable, enable]>
-          options:
-            - clientcomfort
-            - no-content-summary
-            - oversize
-            - splice
-            - bypass-rest-command
-            - bypass-mode-command
-          oversize_limit: <integer>
-          ports: <list or integer>
-          scan_bzip2: <value in [disable, enable]>
-          status: <value in [disable, enable]>
-          uncompressed_nest_limit: <integer>
-          uncompressed_oversize_limit: <integer>
-          ssl_offloaded: <value in [no, yes]>
-          stream_based_uncompressed_limit: <integer>
-          tcp_window_maximum: <integer>
-          tcp_window_minimum: <integer>
-          tcp_window_size: <integer>
-          tcp_window_type: <value in [system, static, dynamic, ...]>
-          explicit_ftp_tls: <value in [disable, enable]>
+          # comfort_amount: <integer>
+          # comfort_interval: <integer>
+          # inspect_all: <value in [disable, enable]>
+          # options:
+          #   - "clientcomfort"
+          #   - "no-content-summary"
+          #   - "oversize"
+          #   - "splice"
+          #   - "bypass-rest-command"
+          #   - "bypass-mode-command"
+          # oversize_limit: <integer>
+          # ports: <list or integer>
+          # scan_bzip2: <value in [disable, enable]>
+          # status: <value in [disable, enable]>
+          # uncompressed_nest_limit: <integer>
+          # uncompressed_oversize_limit: <integer>
+          # ssl_offloaded: <value in [no, yes]>
+          # stream_based_uncompressed_limit: <integer>
+          # tcp_window_maximum: <integer>
+          # tcp_window_minimum: <integer>
+          # tcp_window_size: <integer>
+          # tcp_window_type: <value in [system, static, dynamic, ...]>
+          # explicit_ftp_tls: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -252,29 +270,22 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/profile-protocol-options/{profile-protocol-options}/ftp',
         '/pm/config/global/obj/firewall/profile-protocol-options/{profile-protocol-options}/ftp'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/profile-protocol-options/{profile-protocol-options}/ftp/{ftp}',
-        '/pm/config/global/obj/firewall/profile-protocol-options/{profile-protocol-options}/ftp/{ftp}'
-    ]
-
     url_params = ['adom', 'profile-protocol-options']
     module_primary_key = None
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile-protocol-options': {'type': 'str', 'api_name': 'profile_protocol_options'},
         'profile_protocol_options': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_profileprotocoloptions_ftp': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -299,9 +310,8 @@ def main():
                 'tcp-window-minimum': {'v_range': [['7.0.0', '']], 'type': 'int'},
                 'tcp-window-size': {'v_range': [['7.0.0', '']], 'type': 'int'},
                 'tcp-window-type': {'v_range': [['7.0.0', '']], 'choices': ['system', 'static', 'dynamic', 'auto-tuning'], 'type': 'str'},
-                'explicit-ftp-tls': {'v_range': [['7.0.5', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'explicit-ftp-tls': {'v_range': [['7.0.5', '7.0.14'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -310,14 +320,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_profileprotocoloptions_ftp'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
