@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -147,6 +150,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -155,24 +159,24 @@ EXAMPLES = '''
     - name: Options for the DHCP server to assign IP settings to specific MAC addresses.
       fortinet.fortimanager.fmgr_fsp_vlan_dhcpserver_reservedaddress:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         vlan: <your own value>
         state: present # <value in [present, absent]>
         fsp_vlan_dhcpserver_reservedaddress:
-          action: <value in [assign, block, reserved]>
-          circuit_id: <string>
-          circuit_id_type: <value in [hex, string]>
-          description: <string>
-          id: <integer>
-          ip: <string>
-          mac: <string>
-          remote_id: <string>
-          remote_id_type: <value in [hex, string]>
-          type: <value in [mac, option82]>
+          id: 0 # Required variable, integer
+          # action: <value in [assign, block, reserved]>
+          # circuit_id: <string>
+          # circuit_id_type: <value in [hex, string]>
+          # description: <string>
+          # ip: <string>
+          # mac: <string>
+          # remote_id: <string>
+          # remote_id_type: <value in [hex, string]>
+          # type: <value in [mac, option82]>
 '''
 
 RETURN = '''
@@ -230,6 +234,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'vlan': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'fsp_vlan_dhcpserver_reservedaddress': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
