@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -102,9 +105,10 @@ options:
                     - 'sftp'
                     - 'unknown'
                     - 'scp'
-            default-command-log:
+            default_command_log:
+                aliases: ['default-command-log']
                 type: str
-                description: Deprecated, please rename it to default_command_log. Enable/disable logging unmatched shell commands.
+                description: Enable/disable logging unmatched shell commands.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -125,10 +129,11 @@ options:
                 type: str
                 description: SSH filter profile name.
                 required: true
-            shell-commands:
+            shell_commands:
+                aliases: ['shell-commands']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to shell_commands. Shell-Commands.
+                description: Shell commands.
                 suboptions:
                     action:
                         type: str
@@ -168,14 +173,15 @@ options:
                         choices:
                             - 'regex'
                             - 'simple'
-            file-filter:
+            file_filter:
+                aliases: ['file-filter']
                 type: dict
-                description: Deprecated, please rename it to file_filter.
+                description: File filter.
                 suboptions:
                     entries:
                         type: list
                         elements: dict
-                        description: No description.
+                        description: Entries.
                         suboptions:
                             action:
                                 type: str
@@ -193,22 +199,24 @@ options:
                                     - 'any'
                                     - 'incoming'
                                     - 'outgoing'
-                            file-type:
+                            file_type:
+                                aliases: ['file-type']
                                 type: raw
-                                description: (list) Deprecated, please rename it to file_type.
+                                description: (list) Select file type.
                             filter:
                                 type: str
                                 description: Add a file filter.
-                            password-protected:
+                            password_protected:
+                                aliases: ['password-protected']
                                 type: str
-                                description: Deprecated, please rename it to password_protected. Match password-protected files.
+                                description: Match password-protected files.
                                 choices:
                                     - 'any'
                                     - 'yes'
                             protocol:
                                 type: list
                                 elements: str
-                                description: No description.
+                                description: Protocols to apply with.
                                 choices:
                                     - 'ssh'
                     log:
@@ -217,9 +225,10 @@ options:
                         choices:
                             - 'disable'
                             - 'enable'
-                    scan-archive-contents:
+                    scan_archive_contents:
+                        aliases: ['scan-archive-contents']
                         type: str
-                        description: Deprecated, please rename it to scan_archive_contents. Enable/disable file filter archive contents scan.
+                        description: Enable/disable file filter archive contents scan.
                         choices:
                             - 'disable'
                             - 'enable'
@@ -235,6 +244,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -243,56 +253,54 @@ EXAMPLES = '''
     - name: SSH filter profile.
       fortinet.fortimanager.fmgr_sshfilter_profile:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         sshfilter_profile:
-          block:
-            - x11
-            - shell
-            - exec
-            - port-forward
-            - tun-forward
-            - sftp
-            - unknown
-            - scp
-          default_command_log: <value in [disable, enable]>
-          log:
-            - x11
-            - shell
-            - exec
-            - port-forward
-            - tun-forward
-            - sftp
-            - unknown
-            - scp
-          name: <string>
-          shell_commands:
-            -
-              action: <value in [block, allow]>
-              alert: <value in [disable, enable]>
-              id: <integer>
-              log: <value in [disable, enable]>
-              pattern: <string>
-              severity: <value in [low, medium, high, ...]>
-              type: <value in [regex, simple]>
-          file_filter:
-            entries:
-              -
-                action: <value in [log, block]>
-                comment: <string>
-                direction: <value in [any, incoming, outgoing]>
-                file_type: <list or string>
-                filter: <string>
-                password_protected: <value in [any, yes]>
-                protocol:
-                  - ssh
-            log: <value in [disable, enable]>
-            scan_archive_contents: <value in [disable, enable]>
-            status: <value in [disable, enable]>
+          name: "your value" # Required variable, string
+          # block:
+          #   - "x11"
+          #   - "shell"
+          #   - "exec"
+          #   - "port-forward"
+          #   - "tun-forward"
+          #   - "sftp"
+          #   - "unknown"
+          #   - "scp"
+          # default_command_log: <value in [disable, enable]>
+          # log:
+          #   - "x11"
+          #   - "shell"
+          #   - "exec"
+          #   - "port-forward"
+          #   - "tun-forward"
+          #   - "sftp"
+          #   - "unknown"
+          #   - "scp"
+          # shell_commands:
+          #   - action: <value in [block, allow]>
+          #     alert: <value in [disable, enable]>
+          #     id: <integer>
+          #     log: <value in [disable, enable]>
+          #     pattern: <string>
+          #     severity: <value in [low, medium, high, ...]>
+          #     type: <value in [regex, simple]>
+          # file_filter:
+          #   entries:
+          #     - action: <value in [log, block]>
+          #       comment: <string>
+          #       direction: <value in [any, incoming, outgoing]>
+          #       file_type: <list or string>
+          #       filter: <string>
+          #       password_protected: <value in [any, yes]>
+          #       protocol:
+          #         - "ssh"
+          #   log: <value in [disable, enable]>
+          #   scan_archive_contents: <value in [disable, enable]>
+          #   status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -336,27 +344,20 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/ssh-filter/profile',
         '/pm/config/global/obj/ssh-filter/profile'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/ssh-filter/profile/{profile}',
-        '/pm/config/global/obj/ssh-filter/profile/{profile}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'sshfilter_profile': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -379,29 +380,33 @@ def main():
                     'elements': 'dict'
                 },
                 'file-filter': {
+                    'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']],
                     'type': 'dict',
                     'options': {
                         'entries': {
-                            'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']],
+                            'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']],
                             'type': 'list',
                             'options': {
-                                'action': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'choices': ['log', 'block'], 'type': 'str'},
-                                'comment': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'type': 'str'},
-                                'direction': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'choices': ['any', 'incoming', 'outgoing'], 'type': 'str'},
-                                'file-type': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'type': 'raw'},
-                                'filter': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'type': 'str'},
-                                'password-protected': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'choices': ['any', 'yes'], 'type': 'str'},
-                                'protocol': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'type': 'list', 'choices': ['ssh'], 'elements': 'str'}
+                                'action': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'choices': ['log', 'block'], 'type': 'str'},
+                                'comment': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'type': 'str'},
+                                'direction': {
+                                    'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']],
+                                    'choices': ['any', 'incoming', 'outgoing'],
+                                    'type': 'str'
+                                },
+                                'file-type': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'type': 'raw'},
+                                'filter': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'type': 'str'},
+                                'password-protected': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'choices': ['any', 'yes'], 'type': 'str'},
+                                'protocol': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'type': 'list', 'choices': ['ssh'], 'elements': 'str'}
                             },
                             'elements': 'dict'
                         },
-                        'log': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'scan-archive-contents': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'status': {'v_range': [['6.2.8', '6.2.12'], ['6.4.5', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                        'log': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'scan-archive-contents': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'status': {'v_range': [['6.2.8', '6.2.13'], ['6.4.5', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'}
                     }
                 }
             }
-
         }
     }
 
@@ -410,17 +415,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'sshfilter_profile'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
