@@ -90,6 +90,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -98,13 +99,13 @@ EXAMPLES = '''
     - name: Logging topology settings.
       fortinet.fortimanager.fmgr_system_log_topology:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_log_topology:
-          max_depth: <integer>
-          max_depth_share: <integer>
+          # max_depth: <integer>
+          # max_depth_share: <integer>
 '''
 
 RETURN = '''
