@@ -33,6 +33,19 @@ except ImportError:
 logger = Log()
 
 
+CLOUD_PLATFORMS = ["Google, Inc.", "Msft", "Amazon.com, Inc"]
+AWS = "Amazon.com, Inc"
+AZURE = "Msft"
+GCP = "Google, Inc."
+STORAGE_NODE_STATUS = [
+    "maintenanceblockage",
+    "persistentblockage",
+    "removalfailedandtemporaryblockage",
+    "removalfailedandmaintenanceblockage",
+    "removalfailedandpersistentblockage",
+]
+
+
 def get_json_for_config_file(file_path):
     result = {}
     current_section = None
@@ -72,6 +85,7 @@ class SDSBClusterReconciler:
     def __init__(self, connection_info, state=None):
         self.connection_info = connection_info
         self.provisioner = SDSBClusterProvisioner(self.connection_info)
+        self.storage_node_prov = SDSBStorageNodeProvisioner(connection_info)
         self.state = state
 
     @log_entry_exit
@@ -101,9 +115,80 @@ class SDSBClusterReconciler:
             resp_data = self.remove_storage_node(spec=spec)
         elif state == StateValue.DOWNLOAD_CONFIG_FILE:
             resp_data = self.download_config_file(spec=spec)
+        elif state == StateValue.STOP_REMOVING_STORAGE_NODE:
+            resp_data = self.stop_removing_storage_nodes()
+        elif state == StateValue.REPLACE_STORAGE_NODE:
+            resp_data = self.replace_storage_node(spec=spec)
+        elif state == StateValue.SYSTEM_REQUIREMENT_FILE_PRESENT:
+            resp_data = self.import_system_requirement_file(spec=spec)
+        elif state == StateValue.STOP_STORAGE_CLUSTER:
+            resp_data = self.stop_storage_cluster(spec=spec)
         if resp_data:
             return resp_data
 
+    @log_entry_exit
+    def stop_storage_cluster(self, spec=None):
+        if spec and spec.force and (spec.reboot or spec.config_parameter_setting_mode):
+            raise ValueError(
+                SDSBClusterValidationMsg.BAD_PARAMETERS_FOR_STOP_CLUSTER.value
+            )
+        try:
+            resp = self.provisioner.stop_storage_cluster(spec)
+            msg = SDSBClusterValidationMsg.STOP_CLUSTER_SUCCESS_MSG.value.format(resp)
+            self.connection_info.changed = True
+            return msg
+        except Exception as e:
+            logger.writeException(e)
+            msg = SDSBClusterValidationMsg.STOP_CLUSTER_FAILURE_MSG.value
+            return msg
+
+    @log_entry_exit
+    def import_system_requirement_file(self, spec=None):
+        if spec.system_requirement_file is None:
+            raise ValueError(
+                SDSBClusterValidationMsg.SYSTEM_REQUIREMENT_FILE_REQD.value
+            )
+        else:
+            if not spec.system_requirement_file.endswith("SystemRequirementsFile.yml"):
+                raise ValueError(
+                    SDSBClusterValidationMsg.BAD_SYSTEM_REQUIREMENT_FILE_NAME.value
+                )
+            if not os.path.exists(spec.system_requirement_file):
+                raise ValueError(
+                    SDSBClusterValidationMsg.SYSTEM_REQUIREMENT_FILE_DOES_NOT_EXIST.value.format(
+                        spec.system_requirement_file
+                    )
+                )
+        try:
+            resp = self.provisioner.import_system_requirement_file(spec)
+            msg = SDSBClusterValidationMsg.IMPORT_SYSTEM_REQUIREMET_FILE_SUCCESS_MSG.value.format(
+                resp
+            )
+            self.connection_info.changed = True
+            return msg
+        except Exception as e:
+            logger.writeException(e)
+            msg = (
+                SDSBClusterValidationMsg.IMPORT_SYSTEM_REQUIREMET_FILE_FAILURE_MSG.value
+            )
+            return msg
+
+    @log_entry_exit
+    def stop_removing_storage_nodes(self):
+        try:
+            resp = self.provisioner.stop_removing_storage_nodes()
+            msg = SDSBClusterValidationMsg.STOP_REMOVING_STORAGE_NODE_SUCCESS_MSG.value.format(
+                resp
+            )
+            self.connection_info.changed = True
+            return msg
+        except Exception as e:
+            logger.writeException(e)
+            msg = SDSBClusterValidationMsg.STOP_REMOVING_STORAGE_NODE_FAILURE_MSG.value.format(
+                str(e)
+            )
+            return msg
+
     @log_entry_exit
     def edit_capacity_management_settings(self, spec):
 
@@ -356,13 +441,68 @@ class SDSBClusterReconciler:
 
         return lines
 
+    @log_entry_exit
+    def add_storage_node_azure(self, spec=None):
+        self.create_config_file_for_add_storage_node(spec)
+        exported_config_file = self.download_config_file_azure()
+        resp = self.provisioner.add_storage_node(
+            spec.setup_user_password, exported_config_file=exported_config_file
+        )
+        return resp
+
+    @log_entry_exit
+    def add_storage_node_aws(self, spec=None):
+        if spec.configuration_file is None or spec.vm_configuration_file_s3_uri is None:
+            raise ValueError(SDSBClusterValidationMsg.AWS_ADD_STORAGE_NODE_REQD.value)
+        resp = self.provisioner.add_storage_node(
+            spec.setup_user_password,
+            config_file=spec.configuration_file,
+            vm_configuration_file_s3_uri=spec.vm_configuration_file_s3_uri,
+        )
+        return resp
+
+    @log_entry_exit
+    def add_storage_node_gcp(self, spec=None):
+        resp = self.provisioner.add_storage_node(
+            spec.setup_user_password, config_file=spec.configuration_file
+        )
+        return resp
+
+    @log_entry_exit
+    def add_storage_node_bare_metal(self, spec=None):
+        logger.writeDebug(f"PROV:add_storage_node_bare_metal={spec}")
+        if spec.configuration_file:
+            resp = self.provisioner.add_storage_node(
+                spec.setup_user_password, config_file=spec.configuration_file
+            )
+        else:
+            dest_folder = self.download_and_unzip_config_file()
+            file_name = "SystemConfigurationFile.csv"
+            file_path = f"{dest_folder}/{file_name}"
+            json_object = get_json_for_config_file(file_path)
+            logger.writeDebug(f"json_object = {json_object}")
+            new_json = SDSBClusterExtractor().extract(json_object)
+            logger.writeDebug(f"new_json = {new_json}")
+            self.validate_input_for_storage_nodes(spec, new_json)
+            line_entries = self.get_line_entries(spec)
+            self.append_lines_to_config_file(file_path, line_entries)
+            spec.configuration_file = file_path
+
+            resp = self.provisioner.add_storage_node(
+                spec.setup_user_password, config_file=spec.configuration_file
+            )
+        return resp
+
     @log_entry_exit
     def add_storage_node(self, spec=None):
+        resp = None
         cloud_platforms = ["Google, Inc.", "Msft", "Amazon.com, Inc"]
         platform = self.provisioner.get_platform()
         logger.writeDebug(f"add_storage_node:spec = {spec}  platform = {platform}")
         if platform in cloud_platforms and spec.setup_user_password is None:
-            spec.setup_user_password = "Hitachi1"  # set dummpy password for clouds
+            spec.setup_user_password = (
+                "CHANGE_ME_SET_YOUR_PASSWORD"  # set dummy password for clouds
+            )
 
         if spec.setup_user_password is None:
             raise ValueError(
@@ -375,48 +515,25 @@ class SDSBClusterReconciler:
                         spec.configuration_file
                     )
                 )
-        else:
-            if platform == "Msft":
-                self.create_config_file_for_add_storage_node(spec)
-                exported_config_file = self.download_config_file_azure()
-                logger.writeDebug(f"PROV:add_storage_node:spec={spec}")
-                resp = self.provisioner.add_storage_node(
-                    spec.setup_user_password, exported_config_file=exported_config_file
-                )
 
-            else:
-                dest_folder = self.download_and_unzip_config_file()
-                file_name = "SystemConfigurationFile.csv"
-                file_path = f"{dest_folder}/{file_name}"
-                json_object = get_json_for_config_file(file_path)
-                logger.writeDebug(f"json_object = {json_object}")
-                new_json = SDSBClusterExtractor().extract(json_object)
-                logger.writeDebug(f"new_json = {new_json}")
-                self.validate_input_for_storage_nodes(spec, new_json)
-                line_entries = self.get_line_entries(spec)
-                self.append_lines_to_config_file(file_path, line_entries)
-                spec.configuration_file = file_path
-                # msg = f"""
-                # Testing the construction of the file line
-                # Here is the line:
-                # {line_entries}
-                # """
-                # return msg
+        if platform == "Msft":
+            resp = self.add_storage_node_azure(spec)
 
-                resp = self.provisioner.add_storage_node(
-                    spec.setup_user_password, config_file=spec.configuration_file
-                )
-        msg = f"""
-        Successfully started add storage node to the cluster job. This is a long running operation, and might take an hour or so.
-        You can check the status of the job started periodically using hv_sds_block_job_facts module.
-        ID for this job = {resp}
-        """
+        elif platform == "Amazon.com, Inc":
+            resp = self.add_storage_node_aws(spec)
+
+        elif platform == "Google, Inc.":
+            resp = self.add_storage_node_gcp(spec)
+
+        else:  # Bare Metal
+            resp = self.add_storage_node_bare_metal(spec)
+
+        msg = SDSBClusterValidationMsg.ADD_STORAGE_NODE_SUCCESS_MSG.value.format(resp)
         self.connection_info.changed = True
         return msg
 
     @log_entry_exit
     def create_config_file_for_add_storage_node(self, spec=None):
-        logger.writeDebug(f"PROV:create_config_file:spec={spec}")
         if spec is None:
             raise ValueError(SDSBClusterValidationMsg.SPEC_NONE.value)
 
@@ -424,7 +541,9 @@ class SDSBClusterReconciler:
         if spec.machine_image_id is None:
             raise ValueError(SDSBClusterValidationMsg.SPEC_NONE.value)
 
-        self.provisioner.create_config_file_for_add_storage_node(spec.machine_image_id)
+        self.provisioner.create_config_file_for_add_storage_node(
+            spec.machine_image_id, spec.template_s3_url
+        )
 
     @log_entry_exit
     def append_lines_to_config_file(self, file_path, lines_to_append):
@@ -460,11 +579,9 @@ class SDSBClusterReconciler:
                         )
                     )
             resp = self.provisioner.remove_storage_node(spec.node_id)
-            msg = f"""
-            Successfully started remove storage node from the cluster job. This is a long running operation, and might take few hours.
-            You can check the status of the job started periodically using hv_sds_block_job_facts module.
-            ID for this job = {resp}
-            """
+            msg = SDSBClusterValidationMsg.REMOVE_STORAGE_NODE_SUCCESS_MSG.value.format(
+                resp
+            )
             self.connection_info.changed = True
             return msg
         except Exception as e:
@@ -473,7 +590,6 @@ class SDSBClusterReconciler:
 
     @log_entry_exit
     def create_config_file(self, spec=None):
-        logger.writeDebug(f"PROV:create_config_file:spec={spec}")
         platform = self.provisioner.get_platform()
         logger.writeDebug(f"PROV:create_config_file:platform={platform}")
 
@@ -530,10 +646,8 @@ class SDSBClusterReconciler:
                         spec.machine_image_id
                     )
                 if exf_type == "ReplaceStorageNode":
-                    raise ValueError(
-                        SDSBClusterValidationMsg.OPERATION_NOT_SUPPORTED_YET.value.format(
-                            platform
-                        )
+                    return self.provisioner.create_config_file_to_replace_storage_node(
+                        spec
                     )
             elif exf_type == "AddDrives":
                 if spec.no_of_drives is None:
@@ -587,10 +701,14 @@ class SDSBClusterReconciler:
                         spec.machine_image_id
                     )
                 if exf_type == "ReplaceStorageNode":
-                    raise ValueError(
-                        SDSBClusterValidationMsg.OPERATION_NOT_SUPPORTED_YET.value.format(
-                            platform
+                    if spec.node_id is None:
+                        raise ValueError(
+                            SDSBClusterValidationMsg.NODE_ID_IS_REQD.value.format(
+                                platform
+                            )
                         )
+                    return self.provisioner.create_config_file_to_replace_storage_node(
+                        spec
                     )
             elif exf_type == "AddDrives":
                 if spec.no_of_drives is None:
@@ -613,7 +731,69 @@ class SDSBClusterReconciler:
 
     @log_entry_exit
     def create_config_file_aws(self, spec=None):
-        return self.provisioner.create_config_file("normal")
+        if spec is None:
+            raise ValueError(SDSBClusterValidationMsg.SPEC_REQD_CONFIG_CLOUD.value)
+        aws_export_file_types = [
+            "AddStorageNodes",
+            "ReplaceStorageNode",
+            "AddDrives",
+            "ReplaceDrive",
+            "Normal",
+        ]
+        platform = "AWS"
+        if spec.export_file_type is None:
+            raise ValueError(
+                SDSBClusterValidationMsg.EXPORT_FILE_TYPE_REQD_CONFIG_CLOUD.value.format(
+                    platform
+                )
+            )
+        else:
+            exf_type = spec.export_file_type
+            if exf_type not in aws_export_file_types:
+                raise ValueError(
+                    SDSBClusterValidationMsg.INVALID_EXPORT_FILE_TYPE.value.format(
+                        platform, aws_export_file_types
+                    )
+                )
+
+            if spec.template_s3_url is None:
+                raise ValueError(SDSBClusterValidationMsg.MUST_SPECIFY_S3_URL.value)
+            if not spec.template_s3_url.startswith("https://"):
+                raise ValueError(SDSBClusterValidationMsg.MUST_SPECIFY_S3_URL.value)
+
+            if exf_type == "AddStorageNodes" or exf_type == "ReplaceStorageNode":
+                if spec.machine_image_id is None:
+                    raise ValueError(
+                        SDSBClusterValidationMsg.MACHINE_IMAGE_ID_REQD_CONFIG_CLOUD.value.format(
+                            platform
+                        )
+                    )
+                if exf_type == "AddStorageNodes":
+                    return self.provisioner.create_config_file_for_add_storage_node(
+                        spec.machine_image_id, spec.template_s3_url
+                    )
+                if exf_type == "ReplaceStorageNode":
+                    return self.provisioner.create_config_file_to_replace_storage_node(
+                        spec
+                    )
+            elif exf_type == "AddDrives":
+                if spec.no_of_drives is None:
+                    raise ValueError(
+                        SDSBClusterValidationMsg.NO_OF_DRIVES_REQD_CONFIG_CLOUD.value.format(
+                            platform
+                        )
+                    )
+                return self.provisioner.create_config_file_for_add_drives(
+                    spec.no_of_drives
+                )
+            elif exf_type == "ReplaceDrive":
+                raise ValueError(
+                    SDSBClusterValidationMsg.OPERATION_NOT_SUPPORTED_YET.value.format(
+                        platform
+                    )
+                )
+            elif exf_type == "Normal":
+                return self.provisioner.create_config_file("normal")
 
     @log_entry_exit
     def create_config_file_bare_matel(self, spec=None):
@@ -666,6 +846,120 @@ class SDSBClusterReconciler:
             logger.writeException(e)
             raise Exception(e)
 
+    @log_entry_exit
+    def replace_storage_node(self, spec):
+
+        if (spec.node_id is None and spec.node_name is None) or (
+            spec.node_id is not None and spec.node_name is not None
+        ):
+            raise ValueError(SDSBClusterValidationMsg.NODE_ID_REQUIRED.value)
+        storage_node_prov = SDSBStorageNodeProvisioner(self.connection_info)
+
+        storage_node = None
+        if spec.node_id is None and spec.node_name is not None:
+            storage_node = storage_node_prov.get_storage_node_by_name(spec.node_name)
+            spec.node_id = storage_node.id if storage_node is not None else None
+        else:
+            storage_node = storage_node_prov.get_storage_node_by_id(spec.node_id)
+
+        if storage_node is None:
+            raise ValueError(
+                SDSBClusterValidationMsg.NOT_FOUND_WITH_STORAGE_NODE_ID.value.format(
+                    spec.node_id if spec.node_id is not None else spec.node_name
+                )
+            )
+
+        if storage_node.status.lower() not in STORAGE_NODE_STATUS:
+            raise ValueError(
+                SDSBClusterValidationMsg.STORAGE_NODE_INVALID_STATE.value.format(
+                    spec.node_id, storage_node.status, STORAGE_NODE_STATUS
+                )
+            )
+
+        platform = self.provisioner.get_platform()
+
+        if GCP in platform:
+            try:
+                logger.writeInfo("Replacing storage node on GCP")
+                job_id = (
+                    self.provisioner.gateway.replace_storage_node_with_config_file_gcp(
+                        spec
+                    )
+                )
+                self.connection_info.changed = True
+                return SDSBClusterValidationMsg.REPLACE_STORAGE_NODE_SUCCESS_MSG.value.format(
+                    job_id
+                )
+            except Exception as e:
+                logger.writeError(f"Error replacing storage node on GCP: {e}")
+                return (
+                    SDSBClusterValidationMsg.FAILED_REPLACE_STORAGE_NODE.value.format(e)
+                )
+        elif AZURE in platform:
+            try:
+                # first create config file
+                logger.writeInfo("Creating config file to replace storage node")
+                self.provisioner.create_config_file_to_replace_storage_node(spec)
+                # download the config file
+                logger.writeInfo("Downloading config file to replace storage node")
+                file_name = self.download_config_file_azure()
+                spec.exported_config_file = file_name
+                logger.writeDebug(f"exported_config_file = {spec.exported_config_file}")
+                # replace the storage node
+                logger.writeInfo("Replacing storage node on Azure")
+                job_id = self.provisioner.gateway.replace_storage_node_with_config_file_azure(
+                    spec
+                )
+                self.connection_info.changed = True
+                return SDSBClusterValidationMsg.REPLACE_STORAGE_NODE_SUCCESS_MSG.value.format(
+                    job_id
+                )
+            except Exception as e:
+                logger.writeError(f"Error replacing storage node on Azure: {e}")
+                return (
+                    SDSBClusterValidationMsg.FAILED_REPLACE_STORAGE_NODE.value.format(e)
+                )
+        elif AWS in platform:
+            try:
+                if spec.vm_configuration_file_s3_uri is None:
+                    raise ValueError(SDSBClusterValidationMsg.MUST_SPECIFY_S3_URL.value)
+
+                if spec.configuration_file is None:
+                    raise ValueError(SDSBClusterValidationMsg.CONFIG_FILE_REQD.value)
+
+                job_id = (
+                    self.provisioner.gateway.replace_storage_node_with_config_file_aws(
+                        spec
+                    )
+                )
+                self.connection_info.changed = True
+                return SDSBClusterValidationMsg.REPLACE_STORAGE_NODE_SUCCESS_MSG.value.format(
+                    job_id
+                )
+            except Exception as e:
+                logger.writeError(f"Error replacing storage node on AWS: {e}")
+                return (
+                    SDSBClusterValidationMsg.FAILED_REPLACE_STORAGE_NODE.value.format(e)
+                )
+        else:
+            try:
+                if spec.setup_user_password is None:
+                    raise ValueError(
+                        SDSBClusterValidationMsg.STORAGE_NODE_SETUP_PASSWD_REQD.value
+                    )
+                job_id = self.provisioner.gateway.replace_storage_node_with_config_file_bare_metal(
+                    spec
+                )
+                self.connection_info.changed = True
+                return SDSBClusterValidationMsg.REPLACE_STORAGE_NODE_SUCCESS_MSG.value.format(
+                    job_id
+                )
+            except Exception as e:
+                logger.writeError(f"Error replacing storage node on BareMetal: {e}")
+                return (
+                    SDSBClusterValidationMsg.FAILED_REPLACE_STORAGE_NODE.value.format(e)
+                )
+
     @log_entry_exit
     def get_storage_time_settings(self):
         return self.provisioner.get_storage_time_settings()
