@@ -81,13 +81,16 @@ class VSPHurReconciler:
     def swap_split_hur(self, spec):
         return self.provisioner.swap_split_hur_pair(spec.primary_volume_id, spec)
 
+    @log_entry_exit
+    def secondary_takeover_hur(self, spec):
+        return self.provisioner.secondary_takeover_hur_pair(spec)
+
     @log_entry_exit
     def swap_resync_hur(self, spec):
         return self.provisioner.swap_resync_hur_pair(spec.primary_volume_id, spec)
 
     @log_entry_exit
     def create_hur(self, spec):
-        logger.writeDebug("RC:create_hur:spec={} ", spec)
         self.validate_create_spec(spec)
 
         pvol = self.provisioner.get_volume_by_id(spec.primary_volume_id)
@@ -202,21 +205,29 @@ class VSPHurReconciler:
             resp_data = self.resync_hur(spec)
         elif state == StateValue.SWAP_SPLIT:
             resp_data = self.swap_split_hur(spec)
+        elif state == StateValue.TAKEOVER:
+            resp_data = self.secondary_takeover_hur(spec)
+            return comment, resp_data
         elif state == StateValue.SWAP_RESYNC:
             resp_data = self.swap_resync_hur(spec)
         elif state == StateValue.RESIZE or state == StateValue.EXPAND:
             resp_data = self.resize_hur_copy(spec)
 
         # Match output with Gateway
+        if isinstance(resp_data, str):
+            self.logger.writeDebug("RC:resp_data={}", resp_data)
+            raise ValueError(
+                VSPHurValidateMsg.HUR_OPERATION_FAILED.value.format(resp_data)
+            )
         updated_resp_data = update_response_data(self, resp_data)
         # for key, value in resp_data.items():
         #     new_key = key.replace("svol", "secondary_volume").replace("pvol", "primary_volume").replace("ldev_id", "id")
         #     updated_resp_data[new_key] = value
 
-        # updated_resp_data["primary_hex_volume_id"] = volume_id_to_hex_format(
+        # updated_resp_data["primary_volume_id_hex"] = volume_id_to_hex_format(
         #            updated_resp_data["primary_volume_id"]
         #         )
-        # updated_resp_data["secondary_hex_volume_id"] = volume_id_to_hex_format(
+        # updated_resp_data["secondary_volume_id_hex"] = volume_id_to_hex_format(
         #            updated_resp_data["secondary_volume_id"]
         #         )
         # self.logger.writeDebug("resp_data={}", updated_resp_data)
@@ -401,7 +412,7 @@ class HurInfoExtractor:
             "secondaryVolumeId": int,
             "secondaryVolumeStorageId": int,
             "status": str,
-            "svolAccessMode": str,
+            # "svolAccessMode": str,
             # "type": str,
             # "secondaryVirtualHexVolumeId": int,
             # "entitlementStatus": str,
@@ -436,12 +447,12 @@ class HurInfoExtractor:
                     new_dict[cased_key] = default_value
 
             # new_dict["partner_id"] = "apiadmin"
-            if new_dict.get("primary_hex_volume_id") == "":
-                new_dict["primary_hex_volume_id"] = volume_id_to_hex_format(
+            if new_dict.get("primary_volume_id_hex") == "":
+                new_dict["primary_volume_id_hex"] = volume_id_to_hex_format(
                     new_dict.get("primary_volume_id")
                 )
-            if new_dict.get("secondary_hex_volume_id") == "":
-                new_dict["secondary_hex_volume_id"] = volume_id_to_hex_format(
+            if new_dict.get("secondary_volume_id_hex") == "":
+                new_dict["secondary_volume_id_hex"] = volume_id_to_hex_format(
                     new_dict.get("secondary_volume_id")
                 )
 
@@ -467,12 +478,12 @@ class HurInfoExtractor:
                 new_dict[cased_key] = default_value
 
         # new_dict["partner_id"] = "apiadmin"
-        if new_dict.get("primary_hex_volume_id") == "":
-            new_dict["primary_hex_volume_id"] = volume_id_to_hex_format(
+        if new_dict.get("primary_volume_id_hex") == "":
+            new_dict["primary_volume_id_hex"] = volume_id_to_hex_format(
                 new_dict.get("primary_volume_id")
             )
-        if new_dict.get("secondary_hex_volume_id") == "":
-            new_dict["secondary_hex_volume_id"] = volume_id_to_hex_format(
+        if new_dict.get("secondary_volume_id_hex") == "":
+            new_dict["secondary_volume_id_hex"] = volume_id_to_hex_format(
                 new_dict.get("secondary_volume_id")
             )
 
@@ -493,26 +504,43 @@ class DirectHurCopyPairInfoExtractor:
             "svolStatus": str,
             "copyGroupName": str,
             "copyPairName": str,
-            # "pvolVirtualLdevId":int,
-            # "svolVirtualLdevId":int,
+            "pvolStorageDeviceId": str,
+            "svolStorageDeviceId": str,
             "muNumber": int,
-            # "entitlementStatus": str,
-            # "partnerId": str,
-            # "subscriberId": str,
+            "primaryVolumeIdHex": str,
+            "secondaryVolumeIdHex": str,
         }
 
         self.parameter_mapping = {
-            # "pvol_virtual_ldev_id": "primary_virtual_volume_id",
-            # "svol_virtual_ldev_id": "secondary_virtual_volume_id",
             "mu_number": "mirror_unit_id",
             "pvol_journal_id": "primary_journal_pool",
             "svol_journal_id": "secondary_journal_pool",
             "pvol_ldev_id": "primary_volume_id",
             "svol_ldev_id": "secondary_volume_id",
-            # "pvol_status": "status",
-            # "copy_pair_name": "pair_name",
         }
 
+    # sng20241126 get_serial_number_from_device_id
+    @log_entry_exit
+    def get_serial_number_from_device_id(self, storageDeviceId):
+
+        # for 'pvolStorageDeviceId': 'A34000810045' -> 810045
+        # for 'svolStorageDeviceId': 'A34000810050' -> 810050
+
+        len2 = len(storageDeviceId)
+        # supports up to 7 digits device id
+        len1 = len2 - 8
+
+        result = ""
+        captureOn = False
+        while len1 < len2:
+            char = storageDeviceId[len1]
+            if char != "0" or captureOn:
+                captureOn = True
+                result = result + char
+            len1 = len1 + 1
+
+        return result
+
     def fix_bad_camel_to_snake_conversion(self, key):
         new_key = key.replace("s_s_w_s", "ssws")
         return new_key
@@ -527,13 +555,10 @@ class DirectHurCopyPairInfoExtractor:
 
         for response in responses:
             new_dict = {
-                "primary_volume_storage_id": self.storage_serial_number,
-                "secondary_volume_storage_id": spec.secondary_storage_serial_number,
+                # "primary_volume_storage_id": self.storage_serial_number,
+                # "secondary_volume_storage_id": spec.secondary_storage_serial_number,
                 "copy_rate": "",
                 "mirror_unit_id": "",
-                # "primary_vsm_resource_group_name": "",
-                # "secondary_vsm_resource_group_name": "",
-                "svol_access_mode": "",
             }
             for key, value_type in self.common_properties.items():
                 # Get the corresponding key from the response or its mapped key
@@ -552,16 +577,32 @@ class DirectHurCopyPairInfoExtractor:
                     # Handle missing keys by assigning default values
                     default_value = get_default_value(value_type)
                     new_dict[cased_key] = default_value
-            if new_dict.get("primary_hex_volume_id") == "":
-                new_dict["primary_hex_volume_id"] = volume_id_to_hex_format(
+            if new_dict.get("primary_volume_id_hex") == "":
+                new_dict["primary_volume_id_hex"] = volume_id_to_hex_format(
                     new_dict.get("primary_volume_id")
                 )
                 # new_dict["primary_virtual_volume_id"] = ""
                 # new_dict["primary_virtual_hex_volume_id"] = ""
-            if new_dict.get("secondary_hex_volume_id") == "":
-                new_dict["secondary_hex_volume_id"] = volume_id_to_hex_format(
+            if new_dict.get("secondary_volume_id_hex") == "":
+                new_dict["secondary_volume_id_hex"] = volume_id_to_hex_format(
                     new_dict.get("secondary_volume_id")
                 )
+
+            if response.get("pvolStorageDeviceId"):
+                logger.writeDebug("sngz={}", response.get("pvolStorageDeviceId"))
+                new_dict["primary_volume_storage_id"] = (
+                    self.get_serial_number_from_device_id(
+                        response.get("pvolStorageDeviceId")
+                    )
+                )
+
+            if response.get("svolStorageDeviceId"):
+                new_dict["secondary_volume_storage_id"] = (
+                    self.get_serial_number_from_device_id(
+                        response.get("svolStorageDeviceId")
+                    )
+                )
+
                 # new_dict["secondary_virtual_hex_volume_id"] = ""
                 # new_dict["secondary_virtual_volume_id"] = ""
             if new_dict.get("mu_number"):
@@ -593,10 +634,10 @@ class DirectHurCopyPairInfoExtractor:
                 default_value = get_default_value(value_type)
                 new_dict[cased_key] = default_value
 
-        # if new_dict.get("primary_hex_volume_id") == "" :
-        #     new_dict["primary_hex_volume_id"] = volume_id_to_hex_format(new_dict.get("primary_volume_id"))
-        # if new_dict.get("secondary_hex_volume_id") == "" :
-        #     new_dict["secondary_hex_volume_id"] = volume_id_to_hex_format(new_dict.get("secondary_volume_id"))
+        # if new_dict.get("primary_volume_id_hex") == "" :
+        #     new_dict["primary_volume_id_hex"] = volume_id_to_hex_format(new_dict.get("primary_volume_id"))
+        # if new_dict.get("secondary_volume_id_hex") == "" :
+        #     new_dict["secondary_volume_id_hex"] = volume_id_to_hex_format(new_dict.get("secondary_volume_id"))
 
         return new_dict
 
@@ -629,10 +670,10 @@ def update_response_data(self, resp_data):
         updated_resp_data[new_key] = value
 
     # Convert volume IDs to hex format
-    updated_resp_data["primary_hex_volume_id"] = volume_id_to_hex_format(
+    updated_resp_data["primary_volume_id_hex"] = volume_id_to_hex_format(
         updated_resp_data["primary_volume_id"]
     )
-    updated_resp_data["secondary_hex_volume_id"] = volume_id_to_hex_format(
+    updated_resp_data["secondary_volume_id_hex"] = volume_id_to_hex_format(
         updated_resp_data["secondary_volume_id"]
     )
 
