@@ -85,7 +85,7 @@ EXAMPLES = """
     spec:
       name: "devUser"
       authentication: "local"
-      password: "devPassword"
+      password: "CHANGE_ME_SET_YOUR_PASSWORD"
       group_names: [
         "Audit Log Administrator (View Only) User Group",
         "Storage Administrator (View & Modify) User Group"]
@@ -98,7 +98,7 @@ EXAMPLES = """
       password: "secret"
     spec:
       name: "devUser"
-      password: "devPassword3"
+      password: "CHANGE_ME_SET_YOUR_PASSWORD"
 
 - name: Add Resource Groups to a User Group
   hitachivantara.vspone_block.vsp.hv_user_group:
@@ -143,7 +143,7 @@ users:
       description: The authentication method.
       type: str
       sample: "local"
-    group_names:
+    user_group_names:
       description: The user group names.
       type: list
       elements: str
